import reflex as rx

class BsFill0CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill0CircleFill"


class BsFill0SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill0SquareFill"


class BsFill1CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill1CircleFill"


class BsFill1SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill1SquareFill"


class BsFill2CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill2CircleFill"


class BsFill2SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill2SquareFill"


class BsFill3CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill3CircleFill"


class BsFill3SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill3SquareFill"


class BsFill4CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill4CircleFill"


class BsFill4SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill4SquareFill"


class BsFill5CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill5CircleFill"


class BsFill5SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill5SquareFill"


class BsFill6CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill6CircleFill"


class BsFill6SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill6SquareFill"


class BsFill7CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill7CircleFill"


class BsFill7SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill7SquareFill"


class BsFill8CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill8CircleFill"


class BsFill8SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill8SquareFill"


class BsFill9CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill9CircleFill"


class BsFill9SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFill9SquareFill"


class BsFillAirplaneEnginesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillAirplaneEnginesFill"


class BsFillAirplaneFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillAirplaneFill"


class BsFillAlarmFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillAlarmFill"


class BsFillArchiveFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArchiveFill"


class BsFillArrowDownCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowDownCircleFill"


class BsFillArrowDownLeftCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowDownLeftCircleFill"


class BsFillArrowDownLeftSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowDownLeftSquareFill"


class BsFillArrowDownRightCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowDownRightCircleFill"


class BsFillArrowDownRightSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowDownRightSquareFill"


class BsFillArrowDownSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowDownSquareFill"


class BsFillArrowLeftCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowLeftCircleFill"


class BsFillArrowLeftSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowLeftSquareFill"


class BsFillArrowRightCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowRightCircleFill"


class BsFillArrowRightSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowRightSquareFill"


class BsFillArrowThroughHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowThroughHeartFill"


class BsFillArrowUpCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowUpCircleFill"


class BsFillArrowUpLeftCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowUpLeftCircleFill"


class BsFillArrowUpLeftSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowUpLeftSquareFill"


class BsFillArrowUpRightCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowUpRightCircleFill"


class BsFillArrowUpRightSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowUpRightSquareFill"


class BsFillArrowUpSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillArrowUpSquareFill"


class BsFillAspectRatioFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillAspectRatioFill"


class BsFillAwardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillAwardFill"


class BsFillBackspaceFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBackspaceFill"


class BsFillBackspaceReverseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBackspaceReverseFill"


class BsFillBadge3DFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBadge3DFill"


class BsFillBadge4KFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBadge4KFill"


class BsFillBadge8KFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBadge8KFill"


class BsFillBadgeAdFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBadgeAdFill"


class BsFillBadgeArFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBadgeArFill"


class BsFillBadgeCcFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBadgeCcFill"


class BsFillBadgeHdFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBadgeHdFill"


class BsFillBadgeSdFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBadgeSdFill"


class BsFillBadgeTmFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBadgeTmFill"


class BsFillBadgeVoFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBadgeVoFill"


class BsFillBadgeVrFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBadgeVrFill"


class BsFillBadgeWcFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBadgeWcFill"


class BsFillBagCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBagCheckFill"


class BsFillBagDashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBagDashFill"


class BsFillBagFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBagFill"


class BsFillBagHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBagHeartFill"


class BsFillBagPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBagPlusFill"


class BsFillBagXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBagXFill"


class BsFillBalloonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBalloonFill"


class BsFillBalloonHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBalloonHeartFill"


class BsFillBandaidFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBandaidFill"


class BsFillBarChartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBarChartFill"


class BsFillBarChartLineFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBarChartLineFill"


class BsFillBasketFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBasketFill"


class BsFillBasket2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBasket2Fill"


class BsFillBasket3Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBasket3Fill"


class BsFillBellFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBellFill"


class BsFillBellSlashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBellSlashFill"


class BsFillBinocularsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBinocularsFill"


class BsFillBookFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBookFill"


class BsFillBookmarkCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBookmarkCheckFill"


class BsFillBookmarkDashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBookmarkDashFill"


class BsFillBookmarkFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBookmarkFill"


class BsFillBookmarkHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBookmarkHeartFill"


class BsFillBookmarkPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBookmarkPlusFill"


class BsFillBookmarkStarFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBookmarkStarFill"


class BsFillBookmarkXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBookmarkXFill"


class BsFillBookmarksFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBookmarksFill"


class BsFillBoomboxFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBoomboxFill"


class BsFillBootstrapFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBootstrapFill"


class BsFillBoxFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBoxFill"


class BsFillBoxSeamFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBoxSeamFill"


class BsFillBox2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBox2Fill"


class BsFillBox2HeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBox2HeartFill"


class BsFillBriefcaseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBriefcaseFill"


class BsFillBrightnessAltHighFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBrightnessAltHighFill"


class BsFillBrightnessAltLowFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBrightnessAltLowFill"


class BsFillBrightnessHighFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBrightnessHighFill"


class BsFillBrightnessLowFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBrightnessLowFill"


class BsFillBrushFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBrushFill"


class BsFillBucketFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBucketFill"


class BsFillBugFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBugFill"


class BsFillBuildingFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBuildingFill"


class BsFillBuildingsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBuildingsFill"


class BsFillBusFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillBusFrontFill"


class BsFillCCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCCircleFill"


class BsFillCSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCSquareFill"


class BsFillCalculatorFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalculatorFill"


class BsFillCalendarCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendarCheckFill"


class BsFillCalendarDateFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendarDateFill"


class BsFillCalendarDayFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendarDayFill"


class BsFillCalendarEventFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendarEventFill"


class BsFillCalendarFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendarFill"


class BsFillCalendarHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendarHeartFill"


class BsFillCalendarMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendarMinusFill"


class BsFillCalendarMonthFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendarMonthFill"


class BsFillCalendarPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendarPlusFill"


class BsFillCalendarRangeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendarRangeFill"


class BsFillCalendarWeekFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendarWeekFill"


class BsFillCalendarXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendarXFill"


class BsFillCalendar2CheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar2CheckFill"


class BsFillCalendar2DateFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar2DateFill"


class BsFillCalendar2DayFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar2DayFill"


class BsFillCalendar2EventFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar2EventFill"


class BsFillCalendar2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar2Fill"


class BsFillCalendar2HeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar2HeartFill"


class BsFillCalendar2MinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar2MinusFill"


class BsFillCalendar2MonthFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar2MonthFill"


class BsFillCalendar2PlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar2PlusFill"


class BsFillCalendar2RangeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar2RangeFill"


class BsFillCalendar2WeekFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar2WeekFill"


class BsFillCalendar2XFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar2XFill"


class BsFillCalendar3EventFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar3EventFill"


class BsFillCalendar3Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar3Fill"


class BsFillCalendar3RangeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar3RangeFill"


class BsFillCalendar3WeekFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCalendar3WeekFill"


class BsFillCameraFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCameraFill"


class BsFillCameraReelsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCameraReelsFill"


class BsFillCameraVideoFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCameraVideoFill"


class BsFillCameraVideoOffFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCameraVideoOffFill"


class BsFillCapslockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCapslockFill"


class BsFillCarFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCarFrontFill"


class BsFillCaretDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCaretDownFill"


class BsFillCaretDownSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCaretDownSquareFill"


class BsFillCaretLeftFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCaretLeftFill"


class BsFillCaretLeftSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCaretLeftSquareFill"


class BsFillCaretRightFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCaretRightFill"


class BsFillCaretRightSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCaretRightSquareFill"


class BsFillCaretUpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCaretUpFill"


class BsFillCaretUpSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCaretUpSquareFill"


class BsFillCartCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCartCheckFill"


class BsFillCartDashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCartDashFill"


class BsFillCartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCartFill"


class BsFillCartPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCartPlusFill"


class BsFillCartXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCartXFill"


class BsFillCassetteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCassetteFill"


class BsFillCcCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCcCircleFill"


class BsFillCcSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCcSquareFill"


class BsFillChatDotsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatDotsFill"


class BsFillChatFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatFill"


class BsFillChatHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatHeartFill"


class BsFillChatLeftDotsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatLeftDotsFill"


class BsFillChatLeftFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatLeftFill"


class BsFillChatLeftHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatLeftHeartFill"


class BsFillChatLeftQuoteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatLeftQuoteFill"


class BsFillChatLeftTextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatLeftTextFill"


class BsFillChatQuoteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatQuoteFill"


class BsFillChatRightDotsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatRightDotsFill"


class BsFillChatRightFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatRightFill"


class BsFillChatRightHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatRightHeartFill"


class BsFillChatRightQuoteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatRightQuoteFill"


class BsFillChatRightTextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatRightTextFill"


class BsFillChatSquareDotsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatSquareDotsFill"


class BsFillChatSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatSquareFill"


class BsFillChatSquareHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatSquareHeartFill"


class BsFillChatSquareQuoteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatSquareQuoteFill"


class BsFillChatSquareTextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatSquareTextFill"


class BsFillChatTextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillChatTextFill"


class BsFillCheckCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCheckCircleFill"


class BsFillCheckSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCheckSquareFill"


class BsFillCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCircleFill"


class BsFillClipboardCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClipboardCheckFill"


class BsFillClipboardDataFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClipboardDataFill"


class BsFillClipboardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClipboardFill"


class BsFillClipboardHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClipboardHeartFill"


class BsFillClipboardMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClipboardMinusFill"


class BsFillClipboardPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClipboardPlusFill"


class BsFillClipboardXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClipboardXFill"


class BsFillClipboard2CheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClipboard2CheckFill"


class BsFillClipboard2DataFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClipboard2DataFill"


class BsFillClipboard2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClipboard2Fill"


class BsFillClipboard2HeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClipboard2HeartFill"


class BsFillClipboard2MinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClipboard2MinusFill"


class BsFillClipboard2PlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClipboard2PlusFill"


class BsFillClipboard2PulseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClipboard2PulseFill"


class BsFillClipboard2XFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClipboard2XFill"


class BsFillClockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillClockFill"


class BsFillCloudArrowDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudArrowDownFill"


class BsFillCloudArrowUpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudArrowUpFill"


class BsFillCloudCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudCheckFill"


class BsFillCloudDownloadFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudDownloadFill"


class BsFillCloudDrizzleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudDrizzleFill"


class BsFillCloudFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudFill"


class BsFillCloudFogFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudFogFill"


class BsFillCloudFog2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudFog2Fill"


class BsFillCloudHailFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudHailFill"


class BsFillCloudHazeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudHazeFill"


class BsFillCloudHaze2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudHaze2Fill"


class BsFillCloudLightningFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudLightningFill"


class BsFillCloudLightningRainFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudLightningRainFill"


class BsFillCloudMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudMinusFill"


class BsFillCloudMoonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudMoonFill"


class BsFillCloudPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudPlusFill"


class BsFillCloudRainFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudRainFill"


class BsFillCloudRainHeavyFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudRainHeavyFill"


class BsFillCloudSlashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudSlashFill"


class BsFillCloudSleetFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudSleetFill"


class BsFillCloudSnowFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudSnowFill"


class BsFillCloudSunFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudSunFill"


class BsFillCloudUploadFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudUploadFill"


class BsFillCloudsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudsFill"


class BsFillCloudyFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCloudyFill"


class BsFillCollectionFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCollectionFill"


class BsFillCollectionPlayFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCollectionPlayFill"


class BsFillCompassFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCompassFill"


class BsFillCpuFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCpuFill"


class BsFillCreditCard2BackFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCreditCard2BackFill"


class BsFillCreditCard2FrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCreditCard2FrontFill"


class BsFillCreditCardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCreditCardFill"


class BsFillCupFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCupFill"


class BsFillCupHotFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCupHotFill"


class BsFillCursorFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillCursorFill"


class BsFillDashCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDashCircleFill"


class BsFillDashSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDashSquareFill"


class BsFillDatabaseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDatabaseFill"


class BsFillDeviceHddFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDeviceHddFill"


class BsFillDeviceSsdFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDeviceSsdFill"


class BsFillDiagram2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDiagram2Fill"


class BsFillDiagram3Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDiagram3Fill"


class BsFillDiamondFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDiamondFill"


class BsFillDice1Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDice1Fill"


class BsFillDice2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDice2Fill"


class BsFillDice3Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDice3Fill"


class BsFillDice4Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDice4Fill"


class BsFillDice5Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDice5Fill"


class BsFillDice6Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDice6Fill"


class BsFillDiscFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDiscFill"


class BsFillDisplayFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDisplayFill"


class BsFillDisplayportFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDisplayportFill"


class BsFillDoorClosedFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDoorClosedFill"


class BsFillDoorOpenFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDoorOpenFill"


class BsFillDpadFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDpadFill"


class BsFillDropletFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillDropletFill"


class BsFillEarFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEarFill"


class BsFillEaselFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEaselFill"


class BsFillEasel2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEasel2Fill"


class BsFillEasel3Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEasel3Fill"


class BsFillEggFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEggFill"


class BsFillEjectFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEjectFill"


class BsFillEmojiAngryFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEmojiAngryFill"


class BsFillEmojiDizzyFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEmojiDizzyFill"


class BsFillEmojiExpressionlessFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEmojiExpressionlessFill"


class BsFillEmojiFrownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEmojiFrownFill"


class BsFillEmojiHeartEyesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEmojiHeartEyesFill"


class BsFillEmojiKissFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEmojiKissFill"


class BsFillEmojiLaughingFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEmojiLaughingFill"


class BsFillEmojiNeutralFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEmojiNeutralFill"


class BsFillEmojiSmileFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEmojiSmileFill"


class BsFillEmojiSmileUpsideDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEmojiSmileUpsideDownFill"


class BsFillEmojiSunglassesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEmojiSunglassesFill"


class BsFillEmojiWinkFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEmojiWinkFill"


class BsFillEnvelopeAtFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEnvelopeAtFill"


class BsFillEnvelopeCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEnvelopeCheckFill"


class BsFillEnvelopeDashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEnvelopeDashFill"


class BsFillEnvelopeExclamationFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEnvelopeExclamationFill"


class BsFillEnvelopeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEnvelopeFill"


class BsFillEnvelopeHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEnvelopeHeartFill"


class BsFillEnvelopeOpenFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEnvelopeOpenFill"


class BsFillEnvelopeOpenHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEnvelopeOpenHeartFill"


class BsFillEnvelopePaperFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEnvelopePaperFill"


class BsFillEnvelopePaperHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEnvelopePaperHeartFill"


class BsFillEnvelopePlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEnvelopePlusFill"


class BsFillEnvelopeSlashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEnvelopeSlashFill"


class BsFillEnvelopeXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEnvelopeXFill"


class BsFillEraserFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEraserFill"


class BsFillEvFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEvFrontFill"


class BsFillEvStationFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEvStationFill"


class BsFillExclamationCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillExclamationCircleFill"


class BsFillExclamationDiamondFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillExclamationDiamondFill"


class BsFillExclamationOctagonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillExclamationOctagonFill"


class BsFillExclamationSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillExclamationSquareFill"


class BsFillExclamationTriangleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillExclamationTriangleFill"


class BsFillExplicitFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillExplicitFill"


class BsFillEyeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEyeFill"


class BsFillEyeSlashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillEyeSlashFill"


class BsFillFastForwardBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFastForwardBtnFill"


class BsFillFastForwardCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFastForwardCircleFill"


class BsFillFastForwardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFastForwardFill"


class BsFillFileArrowDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileArrowDownFill"


class BsFillFileArrowUpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileArrowUpFill"


class BsFillFileBarGraphFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileBarGraphFill"


class BsFillFileBinaryFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileBinaryFill"


class BsFillFileBreakFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileBreakFill"


class BsFillFileCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileCheckFill"


class BsFillFileCodeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileCodeFill"


class BsFillFileDiffFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileDiffFill"


class BsFillFileEarmarkArrowDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkArrowDownFill"


class BsFillFileEarmarkArrowUpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkArrowUpFill"


class BsFillFileEarmarkBarGraphFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkBarGraphFill"


class BsFillFileEarmarkBinaryFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkBinaryFill"


class BsFillFileEarmarkBreakFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkBreakFill"


class BsFillFileEarmarkCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkCheckFill"


class BsFillFileEarmarkCodeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkCodeFill"


class BsFillFileEarmarkDiffFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkDiffFill"


class BsFillFileEarmarkEaselFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkEaselFill"


class BsFillFileEarmarkExcelFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkExcelFill"


class BsFillFileEarmarkFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkFill"


class BsFillFileEarmarkFontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkFontFill"


class BsFillFileEarmarkImageFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkImageFill"


class BsFillFileEarmarkLockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkLockFill"


class BsFillFileEarmarkLock2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkLock2Fill"


class BsFillFileEarmarkMedicalFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkMedicalFill"


class BsFillFileEarmarkMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkMinusFill"


class BsFillFileEarmarkMusicFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkMusicFill"


class BsFillFileEarmarkPdfFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkPdfFill"


class BsFillFileEarmarkPersonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkPersonFill"


class BsFillFileEarmarkPlayFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkPlayFill"


class BsFillFileEarmarkPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkPlusFill"


class BsFillFileEarmarkPostFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkPostFill"


class BsFillFileEarmarkPptFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkPptFill"


class BsFillFileEarmarkRichtextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkRichtextFill"


class BsFillFileEarmarkRuledFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkRuledFill"


class BsFillFileEarmarkSlidesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkSlidesFill"


class BsFillFileEarmarkSpreadsheetFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkSpreadsheetFill"


class BsFillFileEarmarkTextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkTextFill"


class BsFillFileEarmarkWordFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkWordFill"


class BsFillFileEarmarkXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkXFill"


class BsFillFileEarmarkZipFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEarmarkZipFill"


class BsFillFileEaselFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileEaselFill"


class BsFillFileExcelFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileExcelFill"


class BsFillFileFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileFill"


class BsFillFileFontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileFontFill"


class BsFillFileImageFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileImageFill"


class BsFillFileLockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileLockFill"


class BsFillFileLock2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileLock2Fill"


class BsFillFileMedicalFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileMedicalFill"


class BsFillFileMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileMinusFill"


class BsFillFileMusicFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileMusicFill"


class BsFillFilePdfFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFilePdfFill"


class BsFillFilePersonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFilePersonFill"


class BsFillFilePlayFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFilePlayFill"


class BsFillFilePlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFilePlusFill"


class BsFillFilePostFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFilePostFill"


class BsFillFilePptFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFilePptFill"


class BsFillFileRichtextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileRichtextFill"


class BsFillFileRuledFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileRuledFill"


class BsFillFileSlidesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileSlidesFill"


class BsFillFileSpreadsheetFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileSpreadsheetFill"


class BsFillFileTextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileTextFill"


class BsFillFileWordFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileWordFill"


class BsFillFileXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileXFill"


class BsFillFileZipFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFileZipFill"


class BsFillFilterCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFilterCircleFill"


class BsFillFilterSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFilterSquareFill"


class BsFillFlagFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFlagFill"


class BsFillFolderFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFolderFill"


class BsFillFolderSymlinkFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFolderSymlinkFill"


class BsFillForwardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillForwardFill"


class BsFillFuelPumpDieselFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFuelPumpDieselFill"


class BsFillFuelPumpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFuelPumpFill"


class BsFillFunnelFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillFunnelFill"


class BsFillGearFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillGearFill"


class BsFillGeoAltFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillGeoAltFill"


class BsFillGeoFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillGeoFill"


class BsFillGiftFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillGiftFill"


class BsFillGrid1X2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillGrid1X2Fill"


class BsFillGrid3X2GapFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillGrid3X2GapFill"


class BsFillGrid3X3GapFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillGrid3X3GapFill"


class BsFillGridFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillGridFill"


class BsFillHCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHCircleFill"


class BsFillHSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHSquareFill"


class BsFillHandIndexFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHandIndexFill"


class BsFillHandIndexThumbFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHandIndexThumbFill"


class BsFillHandThumbsDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHandThumbsDownFill"


class BsFillHandThumbsUpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHandThumbsUpFill"


class BsFillHandbagFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHandbagFill"


class BsFillHddFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHddFill"


class BsFillHddNetworkFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHddNetworkFill"


class BsFillHddRackFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHddRackFill"


class BsFillHddStackFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHddStackFill"


class BsFillHdmiFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHdmiFill"


class BsFillHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHeartFill"


class BsFillHeartPulseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHeartPulseFill"


class BsFillHeartbreakFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHeartbreakFill"


class BsFillHeptagonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHeptagonFill"


class BsFillHexagonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHexagonFill"


class BsFillHospitalFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHospitalFill"


class BsFillHouseAddFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHouseAddFill"


class BsFillHouseCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHouseCheckFill"


class BsFillHouseDashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHouseDashFill"


class BsFillHouseDoorFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHouseDoorFill"


class BsFillHouseDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHouseDownFill"


class BsFillHouseExclamationFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHouseExclamationFill"


class BsFillHouseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHouseFill"


class BsFillHouseGearFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHouseGearFill"


class BsFillHouseHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHouseHeartFill"


class BsFillHouseLockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHouseLockFill"


class BsFillHouseSlashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHouseSlashFill"


class BsFillHouseUpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHouseUpFill"


class BsFillHouseXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHouseXFill"


class BsFillHousesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillHousesFill"


class BsFillImageFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillImageFill"


class BsFillInboxFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillInboxFill"


class BsFillInboxesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillInboxesFill"


class BsFillInfoCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillInfoCircleFill"


class BsFillInfoSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillInfoSquareFill"


class BsFillJournalBookmarkFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillJournalBookmarkFill"


class BsFillKanbanFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillKanbanFill"


class BsFillKeyFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillKeyFill"


class BsFillKeyboardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillKeyboardFill"


class BsFillLampFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillLampFill"


class BsFillLaptopFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillLaptopFill"


class BsFillLayersFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillLayersFill"


class BsFillLightbulbFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillLightbulbFill"


class BsFillLightbulbOffFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillLightbulbOffFill"


class BsFillLightningChargeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillLightningChargeFill"


class BsFillLightningFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillLightningFill"


class BsFillLockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillLockFill"


class BsFillLungsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillLungsFill"


class BsFillMagnetFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMagnetFill"


class BsFillMapFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMapFill"


class BsFillMarkdownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMarkdownFill"


class BsFillMegaphoneFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMegaphoneFill"


class BsFillMenuAppFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMenuAppFill"


class BsFillMenuButtonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMenuButtonFill"


class BsFillMenuButtonWideFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMenuButtonWideFill"


class BsFillMicFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMicFill"


class BsFillMicMuteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMicMuteFill"


class BsFillModemFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillModemFill"


class BsFillMoonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMoonFill"


class BsFillMoonStarsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMoonStarsFill"


class BsFillMortarboardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMortarboardFill"


class BsFillMotherboardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMotherboardFill"


class BsFillMouseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMouseFill"


class BsFillMouse2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMouse2Fill"


class BsFillMouse3Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMouse3Fill"


class BsFillMusicPlayerFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillMusicPlayerFill"


class BsFillNodeMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillNodeMinusFill"


class BsFillNodePlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillNodePlusFill"


class BsFillNutFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillNutFill"


class BsFillOctagonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillOctagonFill"


class BsFillOpticalAudioFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillOpticalAudioFill"


class BsFillPCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPCircleFill"


class BsFillPSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPSquareFill"


class BsFillPaletteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPaletteFill"


class BsFillPassFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPassFill"


class BsFillPatchCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPatchCheckFill"


class BsFillPatchExclamationFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPatchExclamationFill"


class BsFillPatchMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPatchMinusFill"


class BsFillPatchPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPatchPlusFill"


class BsFillPatchQuestionFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPatchQuestionFill"


class BsFillPauseBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPauseBtnFill"


class BsFillPauseCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPauseCircleFill"


class BsFillPauseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPauseFill"


class BsFillPeaceFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPeaceFill"


class BsFillPenFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPenFill"


class BsFillPencilFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPencilFill"


class BsFillPentagonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPentagonFill"


class BsFillPeopleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPeopleFill"


class BsFillPersonBadgeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPersonBadgeFill"


class BsFillPersonCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPersonCheckFill"


class BsFillPersonDashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPersonDashFill"


class BsFillPersonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPersonFill"


class BsFillPersonLinesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPersonLinesFill"


class BsFillPersonPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPersonPlusFill"


class BsFillPersonVcardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPersonVcardFill"


class BsFillPersonXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPersonXFill"


class BsFillPhoneFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPhoneFill"


class BsFillPhoneLandscapeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPhoneLandscapeFill"


class BsFillPhoneVibrateFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPhoneVibrateFill"


class BsFillPieChartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPieChartFill"


class BsFillPiggyBankFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPiggyBankFill"


class BsFillPinAngleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPinAngleFill"


class BsFillPinFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPinFill"


class BsFillPinMapFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPinMapFill"


class BsFillPipFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPipFill"


class BsFillPlayBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPlayBtnFill"


class BsFillPlayCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPlayCircleFill"


class BsFillPlayFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPlayFill"


class BsFillPlugFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPlugFill"


class BsFillPlusCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPlusCircleFill"


class BsFillPlusSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPlusSquareFill"


class BsFillPostageFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPostageFill"


class BsFillPostageHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPostageHeartFill"


class BsFillPostcardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPostcardFill"


class BsFillPostcardHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPostcardHeartFill"


class BsFillPrinterFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPrinterFill"


class BsFillProjectorFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillProjectorFill"


class BsFillPuzzleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillPuzzleFill"


class BsFillQuestionCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillQuestionCircleFill"


class BsFillQuestionDiamondFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillQuestionDiamondFill"


class BsFillQuestionOctagonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillQuestionOctagonFill"


class BsFillQuestionSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillQuestionSquareFill"


class BsFillRCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillRCircleFill"


class BsFillRSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillRSquareFill"


class BsFillRecordBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillRecordBtnFill"


class BsFillRecordCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillRecordCircleFill"


class BsFillRecordFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillRecordFill"


class BsFillRecord2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillRecord2Fill"


class BsFillReplyAllFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillReplyAllFill"


class BsFillReplyFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillReplyFill"


class BsFillRewindBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillRewindBtnFill"


class BsFillRewindCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillRewindCircleFill"


class BsFillRewindFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillRewindFill"


class BsFillRocketFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillRocketFill"


class BsFillRocketTakeoffFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillRocketTakeoffFill"


class BsFillRouterFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillRouterFill"


class BsFillRssFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillRssFill"


class BsFillSafeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSafeFill"


class BsFillSafe2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSafe2Fill"


class BsFillSaveFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSaveFill"


class BsFillSave2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSave2Fill"


class BsFillSdCardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSdCardFill"


class BsFillSearchHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSearchHeartFill"


class BsFillSendCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSendCheckFill"


class BsFillSendDashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSendDashFill"


class BsFillSendExclamationFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSendExclamationFill"


class BsFillSendFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSendFill"


class BsFillSendPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSendPlusFill"


class BsFillSendSlashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSendSlashFill"


class BsFillSendXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSendXFill"


class BsFillShareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillShareFill"


class BsFillShieldFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillShieldFill"


class BsFillShieldLockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillShieldLockFill"


class BsFillShieldSlashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillShieldSlashFill"


class BsFillShiftFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillShiftFill"


class BsFillSignDeadEndFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignDeadEndFill"


class BsFillSignDoNotEnterFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignDoNotEnterFill"


class BsFillSignIntersectionFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignIntersectionFill"


class BsFillSignIntersectionSideFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignIntersectionSideFill"


class BsFillSignIntersectionTFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignIntersectionTFill"


class BsFillSignIntersectionYFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignIntersectionYFill"


class BsFillSignMergeLeftFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignMergeLeftFill"


class BsFillSignMergeRightFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignMergeRightFill"


class BsFillSignNoLeftTurnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignNoLeftTurnFill"


class BsFillSignNoParkingFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignNoParkingFill"


class BsFillSignNoRightTurnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignNoRightTurnFill"


class BsFillSignRailroadFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignRailroadFill"


class BsFillSignStopFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignStopFill"


class BsFillSignStopLightsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignStopLightsFill"


class BsFillSignTurnLeftFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignTurnLeftFill"


class BsFillSignTurnRightFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignTurnRightFill"


class BsFillSignTurnSlightLeftFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignTurnSlightLeftFill"


class BsFillSignTurnSlightRightFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignTurnSlightRightFill"


class BsFillSignYieldFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignYieldFill"


class BsFillSignpost2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignpost2Fill"


class BsFillSignpostFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignpostFill"


class BsFillSignpostSplitFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSignpostSplitFill"


class BsFillSimFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSimFill"


class BsFillSkipBackwardBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSkipBackwardBtnFill"


class BsFillSkipBackwardCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSkipBackwardCircleFill"


class BsFillSkipBackwardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSkipBackwardFill"


class BsFillSkipEndBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSkipEndBtnFill"


class BsFillSkipEndCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSkipEndCircleFill"


class BsFillSkipEndFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSkipEndFill"


class BsFillSkipForwardBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSkipForwardBtnFill"


class BsFillSkipForwardCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSkipForwardCircleFill"


class BsFillSkipForwardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSkipForwardFill"


class BsFillSkipStartBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSkipStartBtnFill"


class BsFillSkipStartCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSkipStartCircleFill"


class BsFillSkipStartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSkipStartFill"


class BsFillSlashCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSlashCircleFill"


class BsFillSlashSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSlashSquareFill"


class BsFillSpeakerFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSpeakerFill"


class BsFillSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSquareFill"


class BsFillStarFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillStarFill"


class BsFillStickiesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillStickiesFill"


class BsFillStickyFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillStickyFill"


class BsFillStopBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillStopBtnFill"


class BsFillStopCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillStopCircleFill"


class BsFillStopFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillStopFill"


class BsFillStoplightsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillStoplightsFill"


class BsFillStopwatchFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillStopwatchFill"


class BsFillSuitClubFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSuitClubFill"


class BsFillSuitDiamondFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSuitDiamondFill"


class BsFillSuitHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSuitHeartFill"


class BsFillSuitSpadeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSuitSpadeFill"


class BsFillSunFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSunFill"


class BsFillSunriseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSunriseFill"


class BsFillSunsetFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillSunsetFill"


class BsFillTabletFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTabletFill"


class BsFillTabletLandscapeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTabletLandscapeFill"


class BsFillTagFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTagFill"


class BsFillTagsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTagsFill"


class BsFillTaxiFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTaxiFrontFill"


class BsFillTelephoneFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTelephoneFill"


class BsFillTelephoneForwardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTelephoneForwardFill"


class BsFillTelephoneInboundFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTelephoneInboundFill"


class BsFillTelephoneMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTelephoneMinusFill"


class BsFillTelephoneOutboundFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTelephoneOutboundFill"


class BsFillTelephonePlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTelephonePlusFill"


class BsFillTelephoneXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTelephoneXFill"


class BsFillTerminalFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTerminalFill"


class BsFillThunderboltFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillThunderboltFill"


class BsFillTicketDetailedFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTicketDetailedFill"


class BsFillTicketFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTicketFill"


class BsFillTicketPerforatedFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTicketPerforatedFill"


class BsFillTrainFreightFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTrainFreightFrontFill"


class BsFillTrainFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTrainFrontFill"


class BsFillTrainLightrailFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTrainLightrailFrontFill"


class BsFillTrashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTrashFill"


class BsFillTrash2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTrash2Fill"


class BsFillTrash3Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTrash3Fill"


class BsFillTreeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTreeFill"


class BsFillTriangleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTriangleFill"


class BsFillTrophyFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTrophyFill"


class BsFillTruckFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTruckFrontFill"


class BsFillTvFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillTvFill"


class BsFillUmbrellaFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillUmbrellaFill"


class BsFillUnlockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillUnlockFill"


class BsFillUsbCFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillUsbCFill"


class BsFillUsbDriveFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillUsbDriveFill"


class BsFillUsbFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillUsbFill"


class BsFillUsbMicroFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillUsbMicroFill"


class BsFillUsbMiniFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillUsbMiniFill"


class BsFillUsbPlugFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillUsbPlugFill"


class BsFillVinylFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillVinylFill"


class BsFillVolumeDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillVolumeDownFill"


class BsFillVolumeMuteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillVolumeMuteFill"


class BsFillVolumeOffFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillVolumeOffFill"


class BsFillVolumeUpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillVolumeUpFill"


class BsFillWalletFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillWalletFill"


class BsFillWebcamFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillWebcamFill"


class BsFillWrenchAdjustableCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillWrenchAdjustableCircleFill"


class BsFillXCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillXCircleFill"


class BsFillXDiamondFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillXDiamondFill"


class BsFillXOctagonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillXOctagonFill"


class BsFillXSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFillXSquareFill"


class BsReverseBackspaceReverse(rx.Component):
    library = "react-icons/bs"
    tag = "BsReverseBackspaceReverse"


class BsReverseLayoutSidebarInsetReverse(rx.Component):
    library = "react-icons/bs"
    tag = "BsReverseLayoutSidebarInsetReverse"


class BsReverseLayoutSidebarReverse(rx.Component):
    library = "react-icons/bs"
    tag = "BsReverseLayoutSidebarReverse"


class BsReverseLayoutTextSidebarReverse(rx.Component):
    library = "react-icons/bs"
    tag = "BsReverseLayoutTextSidebarReverse"


class BsReverseLayoutTextWindowReverse(rx.Component):
    library = "react-icons/bs"
    tag = "BsReverseLayoutTextWindowReverse"


class BsReverseListColumnsReverse(rx.Component):
    library = "react-icons/bs"
    tag = "BsReverseListColumnsReverse"


class Bs0CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs0CircleFill"


class Bs0Circle(rx.Component):
    library = "react-icons/bs"
    tag = "Bs0Circle"


class Bs0SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs0SquareFill"


class Bs0Square(rx.Component):
    library = "react-icons/bs"
    tag = "Bs0Square"


class Bs1CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs1CircleFill"


class Bs1Circle(rx.Component):
    library = "react-icons/bs"
    tag = "Bs1Circle"


class Bs1SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs1SquareFill"


class Bs1Square(rx.Component):
    library = "react-icons/bs"
    tag = "Bs1Square"


class Bs123(rx.Component):
    library = "react-icons/bs"
    tag = "Bs123"


class Bs2CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs2CircleFill"


class Bs2Circle(rx.Component):
    library = "react-icons/bs"
    tag = "Bs2Circle"


class Bs2SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs2SquareFill"


class Bs2Square(rx.Component):
    library = "react-icons/bs"
    tag = "Bs2Square"


class Bs3CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs3CircleFill"


class Bs3Circle(rx.Component):
    library = "react-icons/bs"
    tag = "Bs3Circle"


class Bs3SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs3SquareFill"


class Bs3Square(rx.Component):
    library = "react-icons/bs"
    tag = "Bs3Square"


class Bs4CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs4CircleFill"


class Bs4Circle(rx.Component):
    library = "react-icons/bs"
    tag = "Bs4Circle"


class Bs4SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs4SquareFill"


class Bs4Square(rx.Component):
    library = "react-icons/bs"
    tag = "Bs4Square"


class Bs5CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs5CircleFill"


class Bs5Circle(rx.Component):
    library = "react-icons/bs"
    tag = "Bs5Circle"


class Bs5SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs5SquareFill"


class Bs5Square(rx.Component):
    library = "react-icons/bs"
    tag = "Bs5Square"


class Bs6CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs6CircleFill"


class Bs6Circle(rx.Component):
    library = "react-icons/bs"
    tag = "Bs6Circle"


class Bs6SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs6SquareFill"


class Bs6Square(rx.Component):
    library = "react-icons/bs"
    tag = "Bs6Square"


class Bs7CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs7CircleFill"


class Bs7Circle(rx.Component):
    library = "react-icons/bs"
    tag = "Bs7Circle"


class Bs7SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs7SquareFill"


class Bs7Square(rx.Component):
    library = "react-icons/bs"
    tag = "Bs7Square"


class Bs8CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs8CircleFill"


class Bs8Circle(rx.Component):
    library = "react-icons/bs"
    tag = "Bs8Circle"


class Bs8SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs8SquareFill"


class Bs8Square(rx.Component):
    library = "react-icons/bs"
    tag = "Bs8Square"


class Bs9CircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs9CircleFill"


class Bs9Circle(rx.Component):
    library = "react-icons/bs"
    tag = "Bs9Circle"


class Bs9SquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "Bs9SquareFill"


class Bs9Square(rx.Component):
    library = "react-icons/bs"
    tag = "Bs9Square"


class BsActivity(rx.Component):
    library = "react-icons/bs"
    tag = "BsActivity"


class BsAirplaneEnginesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsAirplaneEnginesFill"


class BsAirplaneEngines(rx.Component):
    library = "react-icons/bs"
    tag = "BsAirplaneEngines"


class BsAirplaneFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsAirplaneFill"


class BsAirplane(rx.Component):
    library = "react-icons/bs"
    tag = "BsAirplane"


class BsAlarmFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsAlarmFill"


class BsAlarm(rx.Component):
    library = "react-icons/bs"
    tag = "BsAlarm"


class BsAlexa(rx.Component):
    library = "react-icons/bs"
    tag = "BsAlexa"


class BsAlignBottom(rx.Component):
    library = "react-icons/bs"
    tag = "BsAlignBottom"


class BsAlignCenter(rx.Component):
    library = "react-icons/bs"
    tag = "BsAlignCenter"


class BsAlignEnd(rx.Component):
    library = "react-icons/bs"
    tag = "BsAlignEnd"


class BsAlignMiddle(rx.Component):
    library = "react-icons/bs"
    tag = "BsAlignMiddle"


class BsAlignStart(rx.Component):
    library = "react-icons/bs"
    tag = "BsAlignStart"


class BsAlignTop(rx.Component):
    library = "react-icons/bs"
    tag = "BsAlignTop"


class BsAlipay(rx.Component):
    library = "react-icons/bs"
    tag = "BsAlipay"


class BsAlt(rx.Component):
    library = "react-icons/bs"
    tag = "BsAlt"


class BsAmd(rx.Component):
    library = "react-icons/bs"
    tag = "BsAmd"


class BsAndroid(rx.Component):
    library = "react-icons/bs"
    tag = "BsAndroid"


class BsAndroid2(rx.Component):
    library = "react-icons/bs"
    tag = "BsAndroid2"


class BsAppIndicator(rx.Component):
    library = "react-icons/bs"
    tag = "BsAppIndicator"


class BsApp(rx.Component):
    library = "react-icons/bs"
    tag = "BsApp"


class BsApple(rx.Component):
    library = "react-icons/bs"
    tag = "BsApple"


class BsArchiveFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArchiveFill"


class BsArchive(rx.Component):
    library = "react-icons/bs"
    tag = "BsArchive"


class BsArrow90DegDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrow90DegDown"


class BsArrow90DegLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrow90DegLeft"


class BsArrow90DegRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrow90DegRight"


class BsArrow90DegUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrow90DegUp"


class BsArrowBarDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowBarDown"


class BsArrowBarLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowBarLeft"


class BsArrowBarRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowBarRight"


class BsArrowBarUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowBarUp"


class BsArrowClockwise(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowClockwise"


class BsArrowCounterclockwise(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowCounterclockwise"


class BsArrowDownCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownCircleFill"


class BsArrowDownCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownCircle"


class BsArrowDownLeftCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownLeftCircleFill"


class BsArrowDownLeftCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownLeftCircle"


class BsArrowDownLeftSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownLeftSquareFill"


class BsArrowDownLeftSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownLeftSquare"


class BsArrowDownLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownLeft"


class BsArrowDownRightCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownRightCircleFill"


class BsArrowDownRightCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownRightCircle"


class BsArrowDownRightSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownRightSquareFill"


class BsArrowDownRightSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownRightSquare"


class BsArrowDownRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownRight"


class BsArrowDownShort(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownShort"


class BsArrowDownSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownSquareFill"


class BsArrowDownSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownSquare"


class BsArrowDownUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDownUp"


class BsArrowDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowDown"


class BsArrowLeftCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowLeftCircleFill"


class BsArrowLeftCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowLeftCircle"


class BsArrowLeftRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowLeftRight"


class BsArrowLeftShort(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowLeftShort"


class BsArrowLeftSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowLeftSquareFill"


class BsArrowLeftSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowLeftSquare"


class BsArrowLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowLeft"


class BsArrowRepeat(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowRepeat"


class BsArrowReturnLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowReturnLeft"


class BsArrowReturnRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowReturnRight"


class BsArrowRightCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowRightCircleFill"


class BsArrowRightCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowRightCircle"


class BsArrowRightShort(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowRightShort"


class BsArrowRightSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowRightSquareFill"


class BsArrowRightSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowRightSquare"


class BsArrowRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowRight"


class BsArrowThroughHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowThroughHeartFill"


class BsArrowThroughHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowThroughHeart"


class BsArrowUpCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUpCircleFill"


class BsArrowUpCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUpCircle"


class BsArrowUpLeftCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUpLeftCircleFill"


class BsArrowUpLeftCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUpLeftCircle"


class BsArrowUpLeftSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUpLeftSquareFill"


class BsArrowUpLeftSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUpLeftSquare"


class BsArrowUpLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUpLeft"


class BsArrowUpRightCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUpRightCircleFill"


class BsArrowUpRightCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUpRightCircle"


class BsArrowUpRightSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUpRightSquareFill"


class BsArrowUpRightSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUpRightSquare"


class BsArrowUpRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUpRight"


class BsArrowUpShort(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUpShort"


class BsArrowUpSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUpSquareFill"


class BsArrowUpSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUpSquare"


class BsArrowUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowUp"


class BsArrowsAngleContract(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowsAngleContract"


class BsArrowsAngleExpand(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowsAngleExpand"


class BsArrowsCollapse(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowsCollapse"


class BsArrowsExpand(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowsExpand"


class BsArrowsFullscreen(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowsFullscreen"


class BsArrowsMove(rx.Component):
    library = "react-icons/bs"
    tag = "BsArrowsMove"


class BsAspectRatioFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsAspectRatioFill"


class BsAspectRatio(rx.Component):
    library = "react-icons/bs"
    tag = "BsAspectRatio"


class BsAsterisk(rx.Component):
    library = "react-icons/bs"
    tag = "BsAsterisk"


class BsAt(rx.Component):
    library = "react-icons/bs"
    tag = "BsAt"


class BsAwardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsAwardFill"


class BsAward(rx.Component):
    library = "react-icons/bs"
    tag = "BsAward"


class BsBack(rx.Component):
    library = "react-icons/bs"
    tag = "BsBack"


class BsBackspaceFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBackspaceFill"


class BsBackspaceReverseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBackspaceReverseFill"


class BsBackspaceReverse(rx.Component):
    library = "react-icons/bs"
    tag = "BsBackspaceReverse"


class BsBackspace(rx.Component):
    library = "react-icons/bs"
    tag = "BsBackspace"


class BsBadge3DFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadge3DFill"


class BsBadge3D(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadge3D"


class BsBadge4KFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadge4KFill"


class BsBadge4K(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadge4K"


class BsBadge8KFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadge8KFill"


class BsBadge8K(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadge8K"


class BsBadgeAdFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeAdFill"


class BsBadgeAd(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeAd"


class BsBadgeArFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeArFill"


class BsBadgeAr(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeAr"


class BsBadgeCcFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeCcFill"


class BsBadgeCc(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeCc"


class BsBadgeHdFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeHdFill"


class BsBadgeHd(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeHd"


class BsBadgeSdFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeSdFill"


class BsBadgeSd(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeSd"


class BsBadgeTmFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeTmFill"


class BsBadgeTm(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeTm"


class BsBadgeVoFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeVoFill"


class BsBadgeVo(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeVo"


class BsBadgeVrFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeVrFill"


class BsBadgeVr(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeVr"


class BsBadgeWcFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeWcFill"


class BsBadgeWc(rx.Component):
    library = "react-icons/bs"
    tag = "BsBadgeWc"


class BsBagCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBagCheckFill"


class BsBagCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsBagCheck"


class BsBagDashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBagDashFill"


class BsBagDash(rx.Component):
    library = "react-icons/bs"
    tag = "BsBagDash"


class BsBagFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBagFill"


class BsBagHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBagHeartFill"


class BsBagHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsBagHeart"


class BsBagPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBagPlusFill"


class BsBagPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsBagPlus"


class BsBagXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBagXFill"


class BsBagX(rx.Component):
    library = "react-icons/bs"
    tag = "BsBagX"


class BsBag(rx.Component):
    library = "react-icons/bs"
    tag = "BsBag"


class BsBalloonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBalloonFill"


class BsBalloonHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBalloonHeartFill"


class BsBalloonHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsBalloonHeart"


class BsBalloon(rx.Component):
    library = "react-icons/bs"
    tag = "BsBalloon"


class BsBandaidFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBandaidFill"


class BsBandaid(rx.Component):
    library = "react-icons/bs"
    tag = "BsBandaid"


class BsBank(rx.Component):
    library = "react-icons/bs"
    tag = "BsBank"


class BsBank2(rx.Component):
    library = "react-icons/bs"
    tag = "BsBank2"


class BsBarChartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBarChartFill"


class BsBarChartLineFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBarChartLineFill"


class BsBarChartLine(rx.Component):
    library = "react-icons/bs"
    tag = "BsBarChartLine"


class BsBarChartSteps(rx.Component):
    library = "react-icons/bs"
    tag = "BsBarChartSteps"


class BsBarChart(rx.Component):
    library = "react-icons/bs"
    tag = "BsBarChart"


class BsBasketFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBasketFill"


class BsBasket(rx.Component):
    library = "react-icons/bs"
    tag = "BsBasket"


class BsBasket2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBasket2Fill"


class BsBasket2(rx.Component):
    library = "react-icons/bs"
    tag = "BsBasket2"


class BsBasket3Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBasket3Fill"


class BsBasket3(rx.Component):
    library = "react-icons/bs"
    tag = "BsBasket3"


class BsBatteryCharging(rx.Component):
    library = "react-icons/bs"
    tag = "BsBatteryCharging"


class BsBatteryFull(rx.Component):
    library = "react-icons/bs"
    tag = "BsBatteryFull"


class BsBatteryHalf(rx.Component):
    library = "react-icons/bs"
    tag = "BsBatteryHalf"


class BsBattery(rx.Component):
    library = "react-icons/bs"
    tag = "BsBattery"


class BsBehance(rx.Component):
    library = "react-icons/bs"
    tag = "BsBehance"


class BsBellFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBellFill"


class BsBellSlashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBellSlashFill"


class BsBellSlash(rx.Component):
    library = "react-icons/bs"
    tag = "BsBellSlash"


class BsBell(rx.Component):
    library = "react-icons/bs"
    tag = "BsBell"


class BsBezier(rx.Component):
    library = "react-icons/bs"
    tag = "BsBezier"


class BsBezier2(rx.Component):
    library = "react-icons/bs"
    tag = "BsBezier2"


class BsBicycle(rx.Component):
    library = "react-icons/bs"
    tag = "BsBicycle"


class BsBinocularsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBinocularsFill"


class BsBinoculars(rx.Component):
    library = "react-icons/bs"
    tag = "BsBinoculars"


class BsBlockquoteLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsBlockquoteLeft"


class BsBlockquoteRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsBlockquoteRight"


class BsBluetooth(rx.Component):
    library = "react-icons/bs"
    tag = "BsBluetooth"


class BsBodyText(rx.Component):
    library = "react-icons/bs"
    tag = "BsBodyText"


class BsBookFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookFill"


class BsBookHalf(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookHalf"


class BsBook(rx.Component):
    library = "react-icons/bs"
    tag = "BsBook"


class BsBookmarkCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmarkCheckFill"


class BsBookmarkCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmarkCheck"


class BsBookmarkDashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmarkDashFill"


class BsBookmarkDash(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmarkDash"


class BsBookmarkFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmarkFill"


class BsBookmarkHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmarkHeartFill"


class BsBookmarkHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmarkHeart"


class BsBookmarkPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmarkPlusFill"


class BsBookmarkPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmarkPlus"


class BsBookmarkStarFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmarkStarFill"


class BsBookmarkStar(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmarkStar"


class BsBookmarkXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmarkXFill"


class BsBookmarkX(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmarkX"


class BsBookmark(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmark"


class BsBookmarksFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmarksFill"


class BsBookmarks(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookmarks"


class BsBookshelf(rx.Component):
    library = "react-icons/bs"
    tag = "BsBookshelf"


class BsBoomboxFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoomboxFill"


class BsBoombox(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoombox"


class BsBootstrapFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBootstrapFill"


class BsBootstrapReboot(rx.Component):
    library = "react-icons/bs"
    tag = "BsBootstrapReboot"


class BsBootstrap(rx.Component):
    library = "react-icons/bs"
    tag = "BsBootstrap"


class BsBorderAll(rx.Component):
    library = "react-icons/bs"
    tag = "BsBorderAll"


class BsBorderBottom(rx.Component):
    library = "react-icons/bs"
    tag = "BsBorderBottom"


class BsBorderCenter(rx.Component):
    library = "react-icons/bs"
    tag = "BsBorderCenter"


class BsBorderInner(rx.Component):
    library = "react-icons/bs"
    tag = "BsBorderInner"


class BsBorderLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsBorderLeft"


class BsBorderMiddle(rx.Component):
    library = "react-icons/bs"
    tag = "BsBorderMiddle"


class BsBorderOuter(rx.Component):
    library = "react-icons/bs"
    tag = "BsBorderOuter"


class BsBorderRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsBorderRight"


class BsBorderStyle(rx.Component):
    library = "react-icons/bs"
    tag = "BsBorderStyle"


class BsBorderTop(rx.Component):
    library = "react-icons/bs"
    tag = "BsBorderTop"


class BsBorderWidth(rx.Component):
    library = "react-icons/bs"
    tag = "BsBorderWidth"


class BsBorder(rx.Component):
    library = "react-icons/bs"
    tag = "BsBorder"


class BsBoundingBoxCircles(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoundingBoxCircles"


class BsBoundingBox(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoundingBox"


class BsBoxArrowDownLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowDownLeft"


class BsBoxArrowDownRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowDownRight"


class BsBoxArrowDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowDown"


class BsBoxArrowInDownLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowInDownLeft"


class BsBoxArrowInDownRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowInDownRight"


class BsBoxArrowInDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowInDown"


class BsBoxArrowInLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowInLeft"


class BsBoxArrowInRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowInRight"


class BsBoxArrowInUpLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowInUpLeft"


class BsBoxArrowInUpRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowInUpRight"


class BsBoxArrowInUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowInUp"


class BsBoxArrowLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowLeft"


class BsBoxArrowRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowRight"


class BsBoxArrowUpLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowUpLeft"


class BsBoxArrowUpRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowUpRight"


class BsBoxArrowUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxArrowUp"


class BsBoxFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxFill"


class BsBoxSeamFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxSeamFill"


class BsBoxSeam(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxSeam"


class BsBox(rx.Component):
    library = "react-icons/bs"
    tag = "BsBox"


class BsBox2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBox2Fill"


class BsBox2HeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBox2HeartFill"


class BsBox2Heart(rx.Component):
    library = "react-icons/bs"
    tag = "BsBox2Heart"


class BsBox2(rx.Component):
    library = "react-icons/bs"
    tag = "BsBox2"


class BsBoxes(rx.Component):
    library = "react-icons/bs"
    tag = "BsBoxes"


class BsBracesAsterisk(rx.Component):
    library = "react-icons/bs"
    tag = "BsBracesAsterisk"


class BsBraces(rx.Component):
    library = "react-icons/bs"
    tag = "BsBraces"


class BsBricks(rx.Component):
    library = "react-icons/bs"
    tag = "BsBricks"


class BsBriefcaseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBriefcaseFill"


class BsBriefcase(rx.Component):
    library = "react-icons/bs"
    tag = "BsBriefcase"


class BsBrightnessAltHighFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBrightnessAltHighFill"


class BsBrightnessAltHigh(rx.Component):
    library = "react-icons/bs"
    tag = "BsBrightnessAltHigh"


class BsBrightnessAltLowFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBrightnessAltLowFill"


class BsBrightnessAltLow(rx.Component):
    library = "react-icons/bs"
    tag = "BsBrightnessAltLow"


class BsBrightnessHighFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBrightnessHighFill"


class BsBrightnessHigh(rx.Component):
    library = "react-icons/bs"
    tag = "BsBrightnessHigh"


class BsBrightnessLowFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBrightnessLowFill"


class BsBrightnessLow(rx.Component):
    library = "react-icons/bs"
    tag = "BsBrightnessLow"


class BsBroadcastPin(rx.Component):
    library = "react-icons/bs"
    tag = "BsBroadcastPin"


class BsBroadcast(rx.Component):
    library = "react-icons/bs"
    tag = "BsBroadcast"


class BsBrowserChrome(rx.Component):
    library = "react-icons/bs"
    tag = "BsBrowserChrome"


class BsBrowserEdge(rx.Component):
    library = "react-icons/bs"
    tag = "BsBrowserEdge"


class BsBrowserFirefox(rx.Component):
    library = "react-icons/bs"
    tag = "BsBrowserFirefox"


class BsBrowserSafari(rx.Component):
    library = "react-icons/bs"
    tag = "BsBrowserSafari"


class BsBrushFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBrushFill"


class BsBrush(rx.Component):
    library = "react-icons/bs"
    tag = "BsBrush"


class BsBucketFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBucketFill"


class BsBucket(rx.Component):
    library = "react-icons/bs"
    tag = "BsBucket"


class BsBugFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBugFill"


class BsBug(rx.Component):
    library = "react-icons/bs"
    tag = "BsBug"


class BsBuildingAdd(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingAdd"


class BsBuildingCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingCheck"


class BsBuildingDash(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingDash"


class BsBuildingDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingDown"


class BsBuildingExclamation(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingExclamation"


class BsBuildingFillAdd(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingFillAdd"


class BsBuildingFillCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingFillCheck"


class BsBuildingFillDash(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingFillDash"


class BsBuildingFillDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingFillDown"


class BsBuildingFillExclamation(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingFillExclamation"


class BsBuildingFillGear(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingFillGear"


class BsBuildingFillLock(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingFillLock"


class BsBuildingFillSlash(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingFillSlash"


class BsBuildingFillUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingFillUp"


class BsBuildingFillX(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingFillX"


class BsBuildingFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingFill"


class BsBuildingGear(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingGear"


class BsBuildingLock(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingLock"


class BsBuildingSlash(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingSlash"


class BsBuildingUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingUp"


class BsBuildingX(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingX"


class BsBuilding(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuilding"


class BsBuildingsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildingsFill"


class BsBuildings(rx.Component):
    library = "react-icons/bs"
    tag = "BsBuildings"


class BsBullseye(rx.Component):
    library = "react-icons/bs"
    tag = "BsBullseye"


class BsBusFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsBusFrontFill"


class BsBusFront(rx.Component):
    library = "react-icons/bs"
    tag = "BsBusFront"


class BsCCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCCircleFill"


class BsCCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsCCircle"


class BsCSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCSquareFill"


class BsCSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsCSquare"


class BsCalculatorFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalculatorFill"


class BsCalculator(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalculator"


class BsCalendarCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarCheckFill"


class BsCalendarCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarCheck"


class BsCalendarDateFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarDateFill"


class BsCalendarDate(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarDate"


class BsCalendarDayFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarDayFill"


class BsCalendarDay(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarDay"


class BsCalendarEventFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarEventFill"


class BsCalendarEvent(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarEvent"


class BsCalendarFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarFill"


class BsCalendarHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarHeartFill"


class BsCalendarHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarHeart"


class BsCalendarMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarMinusFill"


class BsCalendarMinus(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarMinus"


class BsCalendarMonthFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarMonthFill"


class BsCalendarMonth(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarMonth"


class BsCalendarPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarPlusFill"


class BsCalendarPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarPlus"


class BsCalendarRangeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarRangeFill"


class BsCalendarRange(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarRange"


class BsCalendarWeekFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarWeekFill"


class BsCalendarWeek(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarWeek"


class BsCalendarXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarXFill"


class BsCalendarX(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendarX"


class BsCalendar(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar"


class BsCalendar2CheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2CheckFill"


class BsCalendar2Check(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2Check"


class BsCalendar2DateFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2DateFill"


class BsCalendar2Date(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2Date"


class BsCalendar2DayFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2DayFill"


class BsCalendar2Day(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2Day"


class BsCalendar2EventFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2EventFill"


class BsCalendar2Event(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2Event"


class BsCalendar2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2Fill"


class BsCalendar2HeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2HeartFill"


class BsCalendar2Heart(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2Heart"


class BsCalendar2MinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2MinusFill"


class BsCalendar2Minus(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2Minus"


class BsCalendar2MonthFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2MonthFill"


class BsCalendar2Month(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2Month"


class BsCalendar2PlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2PlusFill"


class BsCalendar2Plus(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2Plus"


class BsCalendar2RangeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2RangeFill"


class BsCalendar2Range(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2Range"


class BsCalendar2WeekFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2WeekFill"


class BsCalendar2Week(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2Week"


class BsCalendar2XFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2XFill"


class BsCalendar2X(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2X"


class BsCalendar2(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar2"


class BsCalendar3EventFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar3EventFill"


class BsCalendar3Event(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar3Event"


class BsCalendar3Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar3Fill"


class BsCalendar3RangeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar3RangeFill"


class BsCalendar3Range(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar3Range"


class BsCalendar3WeekFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar3WeekFill"


class BsCalendar3Week(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar3Week"


class BsCalendar3(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar3"


class BsCalendar4Event(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar4Event"


class BsCalendar4Range(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar4Range"


class BsCalendar4Week(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar4Week"


class BsCalendar4(rx.Component):
    library = "react-icons/bs"
    tag = "BsCalendar4"


class BsCameraFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCameraFill"


class BsCameraReelsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCameraReelsFill"


class BsCameraReels(rx.Component):
    library = "react-icons/bs"
    tag = "BsCameraReels"


class BsCameraVideoFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCameraVideoFill"


class BsCameraVideoOffFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCameraVideoOffFill"


class BsCameraVideoOff(rx.Component):
    library = "react-icons/bs"
    tag = "BsCameraVideoOff"


class BsCameraVideo(rx.Component):
    library = "react-icons/bs"
    tag = "BsCameraVideo"


class BsCamera(rx.Component):
    library = "react-icons/bs"
    tag = "BsCamera"


class BsCamera2(rx.Component):
    library = "react-icons/bs"
    tag = "BsCamera2"


class BsCapslockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCapslockFill"


class BsCapslock(rx.Component):
    library = "react-icons/bs"
    tag = "BsCapslock"


class BsCapsulePill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCapsulePill"


class BsCapsule(rx.Component):
    library = "react-icons/bs"
    tag = "BsCapsule"


class BsCarFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCarFrontFill"


class BsCarFront(rx.Component):
    library = "react-icons/bs"
    tag = "BsCarFront"


class BsCardChecklist(rx.Component):
    library = "react-icons/bs"
    tag = "BsCardChecklist"


class BsCardHeading(rx.Component):
    library = "react-icons/bs"
    tag = "BsCardHeading"


class BsCardImage(rx.Component):
    library = "react-icons/bs"
    tag = "BsCardImage"


class BsCardList(rx.Component):
    library = "react-icons/bs"
    tag = "BsCardList"


class BsCardText(rx.Component):
    library = "react-icons/bs"
    tag = "BsCardText"


class BsCaretDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretDownFill"


class BsCaretDownSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretDownSquareFill"


class BsCaretDownSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretDownSquare"


class BsCaretDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretDown"


class BsCaretLeftFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretLeftFill"


class BsCaretLeftSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretLeftSquareFill"


class BsCaretLeftSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretLeftSquare"


class BsCaretLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretLeft"


class BsCaretRightFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretRightFill"


class BsCaretRightSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretRightSquareFill"


class BsCaretRightSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretRightSquare"


class BsCaretRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretRight"


class BsCaretUpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretUpFill"


class BsCaretUpSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretUpSquareFill"


class BsCaretUpSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretUpSquare"


class BsCaretUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsCaretUp"


class BsCartCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCartCheckFill"


class BsCartCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsCartCheck"


class BsCartDashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCartDashFill"


class BsCartDash(rx.Component):
    library = "react-icons/bs"
    tag = "BsCartDash"


class BsCartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCartFill"


class BsCartPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCartPlusFill"


class BsCartPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsCartPlus"


class BsCartXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCartXFill"


class BsCartX(rx.Component):
    library = "react-icons/bs"
    tag = "BsCartX"


class BsCart(rx.Component):
    library = "react-icons/bs"
    tag = "BsCart"


class BsCart2(rx.Component):
    library = "react-icons/bs"
    tag = "BsCart2"


class BsCart3(rx.Component):
    library = "react-icons/bs"
    tag = "BsCart3"


class BsCart4(rx.Component):
    library = "react-icons/bs"
    tag = "BsCart4"


class BsCashCoin(rx.Component):
    library = "react-icons/bs"
    tag = "BsCashCoin"


class BsCashStack(rx.Component):
    library = "react-icons/bs"
    tag = "BsCashStack"


class BsCash(rx.Component):
    library = "react-icons/bs"
    tag = "BsCash"


class BsCassetteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCassetteFill"


class BsCassette(rx.Component):
    library = "react-icons/bs"
    tag = "BsCassette"


class BsCast(rx.Component):
    library = "react-icons/bs"
    tag = "BsCast"


class BsCcCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCcCircleFill"


class BsCcCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsCcCircle"


class BsCcSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCcSquareFill"


class BsCcSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsCcSquare"


class BsChatDotsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatDotsFill"


class BsChatDots(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatDots"


class BsChatFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatFill"


class BsChatHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatHeartFill"


class BsChatHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatHeart"


class BsChatLeftDotsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatLeftDotsFill"


class BsChatLeftDots(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatLeftDots"


class BsChatLeftFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatLeftFill"


class BsChatLeftHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatLeftHeartFill"


class BsChatLeftHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatLeftHeart"


class BsChatLeftQuoteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatLeftQuoteFill"


class BsChatLeftQuote(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatLeftQuote"


class BsChatLeftTextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatLeftTextFill"


class BsChatLeftText(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatLeftText"


class BsChatLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatLeft"


class BsChatQuoteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatQuoteFill"


class BsChatQuote(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatQuote"


class BsChatRightDotsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatRightDotsFill"


class BsChatRightDots(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatRightDots"


class BsChatRightFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatRightFill"


class BsChatRightHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatRightHeartFill"


class BsChatRightHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatRightHeart"


class BsChatRightQuoteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatRightQuoteFill"


class BsChatRightQuote(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatRightQuote"


class BsChatRightTextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatRightTextFill"


class BsChatRightText(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatRightText"


class BsChatRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatRight"


class BsChatSquareDotsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatSquareDotsFill"


class BsChatSquareDots(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatSquareDots"


class BsChatSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatSquareFill"


class BsChatSquareHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatSquareHeartFill"


class BsChatSquareHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatSquareHeart"


class BsChatSquareQuoteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatSquareQuoteFill"


class BsChatSquareQuote(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatSquareQuote"


class BsChatSquareTextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatSquareTextFill"


class BsChatSquareText(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatSquareText"


class BsChatSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatSquare"


class BsChatTextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatTextFill"


class BsChatText(rx.Component):
    library = "react-icons/bs"
    tag = "BsChatText"


class BsChat(rx.Component):
    library = "react-icons/bs"
    tag = "BsChat"


class BsCheckAll(rx.Component):
    library = "react-icons/bs"
    tag = "BsCheckAll"


class BsCheckCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCheckCircleFill"


class BsCheckCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsCheckCircle"


class BsCheckLg(rx.Component):
    library = "react-icons/bs"
    tag = "BsCheckLg"


class BsCheckSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCheckSquareFill"


class BsCheckSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsCheckSquare"


class BsCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsCheck"


class BsCheck2All(rx.Component):
    library = "react-icons/bs"
    tag = "BsCheck2All"


class BsCheck2Circle(rx.Component):
    library = "react-icons/bs"
    tag = "BsCheck2Circle"


class BsCheck2Square(rx.Component):
    library = "react-icons/bs"
    tag = "BsCheck2Square"


class BsCheck2(rx.Component):
    library = "react-icons/bs"
    tag = "BsCheck2"


class BsChevronBarContract(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronBarContract"


class BsChevronBarDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronBarDown"


class BsChevronBarExpand(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronBarExpand"


class BsChevronBarLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronBarLeft"


class BsChevronBarRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronBarRight"


class BsChevronBarUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronBarUp"


class BsChevronCompactDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronCompactDown"


class BsChevronCompactLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronCompactLeft"


class BsChevronCompactRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronCompactRight"


class BsChevronCompactUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronCompactUp"


class BsChevronContract(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronContract"


class BsChevronDoubleDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronDoubleDown"


class BsChevronDoubleLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronDoubleLeft"


class BsChevronDoubleRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronDoubleRight"


class BsChevronDoubleUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronDoubleUp"


class BsChevronDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronDown"


class BsChevronExpand(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronExpand"


class BsChevronLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronLeft"


class BsChevronRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronRight"


class BsChevronUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsChevronUp"


class BsCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCircleFill"


class BsCircleHalf(rx.Component):
    library = "react-icons/bs"
    tag = "BsCircleHalf"


class BsCircleSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsCircleSquare"


class BsCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsCircle"


class BsClipboardCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboardCheckFill"


class BsClipboardCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboardCheck"


class BsClipboardDataFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboardDataFill"


class BsClipboardData(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboardData"


class BsClipboardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboardFill"


class BsClipboardHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboardHeartFill"


class BsClipboardHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboardHeart"


class BsClipboardMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboardMinusFill"


class BsClipboardMinus(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboardMinus"


class BsClipboardPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboardPlusFill"


class BsClipboardPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboardPlus"


class BsClipboardPulse(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboardPulse"


class BsClipboardXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboardXFill"


class BsClipboardX(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboardX"


class BsClipboard(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard"


class BsClipboard2CheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2CheckFill"


class BsClipboard2Check(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2Check"


class BsClipboard2DataFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2DataFill"


class BsClipboard2Data(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2Data"


class BsClipboard2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2Fill"


class BsClipboard2HeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2HeartFill"


class BsClipboard2Heart(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2Heart"


class BsClipboard2MinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2MinusFill"


class BsClipboard2Minus(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2Minus"


class BsClipboard2PlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2PlusFill"


class BsClipboard2Plus(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2Plus"


class BsClipboard2PulseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2PulseFill"


class BsClipboard2Pulse(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2Pulse"


class BsClipboard2XFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2XFill"


class BsClipboard2X(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2X"


class BsClipboard2(rx.Component):
    library = "react-icons/bs"
    tag = "BsClipboard2"


class BsClockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsClockFill"


class BsClockHistory(rx.Component):
    library = "react-icons/bs"
    tag = "BsClockHistory"


class BsClock(rx.Component):
    library = "react-icons/bs"
    tag = "BsClock"


class BsCloudArrowDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudArrowDownFill"


class BsCloudArrowDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudArrowDown"


class BsCloudArrowUpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudArrowUpFill"


class BsCloudArrowUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudArrowUp"


class BsCloudCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudCheckFill"


class BsCloudCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudCheck"


class BsCloudDownloadFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudDownloadFill"


class BsCloudDownload(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudDownload"


class BsCloudDrizzleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudDrizzleFill"


class BsCloudDrizzle(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudDrizzle"


class BsCloudFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudFill"


class BsCloudFogFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudFogFill"


class BsCloudFog(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudFog"


class BsCloudFog2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudFog2Fill"


class BsCloudFog2(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudFog2"


class BsCloudHailFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudHailFill"


class BsCloudHail(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudHail"


class BsCloudHazeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudHazeFill"


class BsCloudHaze(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudHaze"


class BsCloudHaze2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudHaze2Fill"


class BsCloudHaze2(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudHaze2"


class BsCloudLightningFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudLightningFill"


class BsCloudLightningRainFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudLightningRainFill"


class BsCloudLightningRain(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudLightningRain"


class BsCloudLightning(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudLightning"


class BsCloudMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudMinusFill"


class BsCloudMinus(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudMinus"


class BsCloudMoonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudMoonFill"


class BsCloudMoon(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudMoon"


class BsCloudPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudPlusFill"


class BsCloudPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudPlus"


class BsCloudRainFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudRainFill"


class BsCloudRainHeavyFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudRainHeavyFill"


class BsCloudRainHeavy(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudRainHeavy"


class BsCloudRain(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudRain"


class BsCloudSlashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudSlashFill"


class BsCloudSlash(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudSlash"


class BsCloudSleetFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudSleetFill"


class BsCloudSleet(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudSleet"


class BsCloudSnowFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudSnowFill"


class BsCloudSnow(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudSnow"


class BsCloudSunFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudSunFill"


class BsCloudSun(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudSun"


class BsCloudUploadFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudUploadFill"


class BsCloudUpload(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudUpload"


class BsCloud(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloud"


class BsCloudsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudsFill"


class BsClouds(rx.Component):
    library = "react-icons/bs"
    tag = "BsClouds"


class BsCloudyFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudyFill"


class BsCloudy(rx.Component):
    library = "react-icons/bs"
    tag = "BsCloudy"


class BsCodeSlash(rx.Component):
    library = "react-icons/bs"
    tag = "BsCodeSlash"


class BsCodeSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsCodeSquare"


class BsCode(rx.Component):
    library = "react-icons/bs"
    tag = "BsCode"


class BsCoin(rx.Component):
    library = "react-icons/bs"
    tag = "BsCoin"


class BsCollectionFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCollectionFill"


class BsCollectionPlayFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCollectionPlayFill"


class BsCollectionPlay(rx.Component):
    library = "react-icons/bs"
    tag = "BsCollectionPlay"


class BsCollection(rx.Component):
    library = "react-icons/bs"
    tag = "BsCollection"


class BsColumnsGap(rx.Component):
    library = "react-icons/bs"
    tag = "BsColumnsGap"


class BsColumns(rx.Component):
    library = "react-icons/bs"
    tag = "BsColumns"


class BsCommand(rx.Component):
    library = "react-icons/bs"
    tag = "BsCommand"


class BsCompassFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCompassFill"


class BsCompass(rx.Component):
    library = "react-icons/bs"
    tag = "BsCompass"


class BsConeStriped(rx.Component):
    library = "react-icons/bs"
    tag = "BsConeStriped"


class BsCone(rx.Component):
    library = "react-icons/bs"
    tag = "BsCone"


class BsController(rx.Component):
    library = "react-icons/bs"
    tag = "BsController"


class BsCpuFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCpuFill"


class BsCpu(rx.Component):
    library = "react-icons/bs"
    tag = "BsCpu"


class BsCreditCard2BackFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCreditCard2BackFill"


class BsCreditCard2Back(rx.Component):
    library = "react-icons/bs"
    tag = "BsCreditCard2Back"


class BsCreditCard2FrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCreditCard2FrontFill"


class BsCreditCard2Front(rx.Component):
    library = "react-icons/bs"
    tag = "BsCreditCard2Front"


class BsCreditCardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCreditCardFill"


class BsCreditCard(rx.Component):
    library = "react-icons/bs"
    tag = "BsCreditCard"


class BsCrop(rx.Component):
    library = "react-icons/bs"
    tag = "BsCrop"


class BsCupFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCupFill"


class BsCupHotFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCupHotFill"


class BsCupHot(rx.Component):
    library = "react-icons/bs"
    tag = "BsCupHot"


class BsCupStraw(rx.Component):
    library = "react-icons/bs"
    tag = "BsCupStraw"


class BsCup(rx.Component):
    library = "react-icons/bs"
    tag = "BsCup"


class BsCurrencyBitcoin(rx.Component):
    library = "react-icons/bs"
    tag = "BsCurrencyBitcoin"


class BsCurrencyDollar(rx.Component):
    library = "react-icons/bs"
    tag = "BsCurrencyDollar"


class BsCurrencyEuro(rx.Component):
    library = "react-icons/bs"
    tag = "BsCurrencyEuro"


class BsCurrencyExchange(rx.Component):
    library = "react-icons/bs"
    tag = "BsCurrencyExchange"


class BsCurrencyPound(rx.Component):
    library = "react-icons/bs"
    tag = "BsCurrencyPound"


class BsCurrencyRupee(rx.Component):
    library = "react-icons/bs"
    tag = "BsCurrencyRupee"


class BsCurrencyYen(rx.Component):
    library = "react-icons/bs"
    tag = "BsCurrencyYen"


class BsCursorFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsCursorFill"


class BsCursorText(rx.Component):
    library = "react-icons/bs"
    tag = "BsCursorText"


class BsCursor(rx.Component):
    library = "react-icons/bs"
    tag = "BsCursor"


class BsDashCircleDotted(rx.Component):
    library = "react-icons/bs"
    tag = "BsDashCircleDotted"


class BsDashCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDashCircleFill"


class BsDashCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsDashCircle"


class BsDashLg(rx.Component):
    library = "react-icons/bs"
    tag = "BsDashLg"


class BsDashSquareDotted(rx.Component):
    library = "react-icons/bs"
    tag = "BsDashSquareDotted"


class BsDashSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDashSquareFill"


class BsDashSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsDashSquare"


class BsDash(rx.Component):
    library = "react-icons/bs"
    tag = "BsDash"


class BsDatabaseAdd(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseAdd"


class BsDatabaseCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseCheck"


class BsDatabaseDash(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseDash"


class BsDatabaseDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseDown"


class BsDatabaseExclamation(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseExclamation"


class BsDatabaseFillAdd(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseFillAdd"


class BsDatabaseFillCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseFillCheck"


class BsDatabaseFillDash(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseFillDash"


class BsDatabaseFillDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseFillDown"


class BsDatabaseFillExclamation(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseFillExclamation"


class BsDatabaseFillGear(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseFillGear"


class BsDatabaseFillLock(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseFillLock"


class BsDatabaseFillSlash(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseFillSlash"


class BsDatabaseFillUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseFillUp"


class BsDatabaseFillX(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseFillX"


class BsDatabaseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseFill"


class BsDatabaseGear(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseGear"


class BsDatabaseLock(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseLock"


class BsDatabaseSlash(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseSlash"


class BsDatabaseUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseUp"


class BsDatabaseX(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabaseX"


class BsDatabase(rx.Component):
    library = "react-icons/bs"
    tag = "BsDatabase"


class BsDeviceHddFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDeviceHddFill"


class BsDeviceHdd(rx.Component):
    library = "react-icons/bs"
    tag = "BsDeviceHdd"


class BsDeviceSsdFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDeviceSsdFill"


class BsDeviceSsd(rx.Component):
    library = "react-icons/bs"
    tag = "BsDeviceSsd"


class BsDiagram2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDiagram2Fill"


class BsDiagram2(rx.Component):
    library = "react-icons/bs"
    tag = "BsDiagram2"


class BsDiagram3Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDiagram3Fill"


class BsDiagram3(rx.Component):
    library = "react-icons/bs"
    tag = "BsDiagram3"


class BsDiamondFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDiamondFill"


class BsDiamondHalf(rx.Component):
    library = "react-icons/bs"
    tag = "BsDiamondHalf"


class BsDiamond(rx.Component):
    library = "react-icons/bs"
    tag = "BsDiamond"


class BsDice1Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDice1Fill"


class BsDice1(rx.Component):
    library = "react-icons/bs"
    tag = "BsDice1"


class BsDice2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDice2Fill"


class BsDice2(rx.Component):
    library = "react-icons/bs"
    tag = "BsDice2"


class BsDice3Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDice3Fill"


class BsDice3(rx.Component):
    library = "react-icons/bs"
    tag = "BsDice3"


class BsDice4Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDice4Fill"


class BsDice4(rx.Component):
    library = "react-icons/bs"
    tag = "BsDice4"


class BsDice5Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDice5Fill"


class BsDice5(rx.Component):
    library = "react-icons/bs"
    tag = "BsDice5"


class BsDice6Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDice6Fill"


class BsDice6(rx.Component):
    library = "react-icons/bs"
    tag = "BsDice6"


class BsDiscFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDiscFill"


class BsDisc(rx.Component):
    library = "react-icons/bs"
    tag = "BsDisc"


class BsDiscord(rx.Component):
    library = "react-icons/bs"
    tag = "BsDiscord"


class BsDisplayFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDisplayFill"


class BsDisplay(rx.Component):
    library = "react-icons/bs"
    tag = "BsDisplay"


class BsDisplayportFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDisplayportFill"


class BsDisplayport(rx.Component):
    library = "react-icons/bs"
    tag = "BsDisplayport"


class BsDistributeHorizontal(rx.Component):
    library = "react-icons/bs"
    tag = "BsDistributeHorizontal"


class BsDistributeVertical(rx.Component):
    library = "react-icons/bs"
    tag = "BsDistributeVertical"


class BsDoorClosedFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDoorClosedFill"


class BsDoorClosed(rx.Component):
    library = "react-icons/bs"
    tag = "BsDoorClosed"


class BsDoorOpenFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDoorOpenFill"


class BsDoorOpen(rx.Component):
    library = "react-icons/bs"
    tag = "BsDoorOpen"


class BsDot(rx.Component):
    library = "react-icons/bs"
    tag = "BsDot"


class BsDownload(rx.Component):
    library = "react-icons/bs"
    tag = "BsDownload"


class BsDpadFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDpadFill"


class BsDpad(rx.Component):
    library = "react-icons/bs"
    tag = "BsDpad"


class BsDribbble(rx.Component):
    library = "react-icons/bs"
    tag = "BsDribbble"


class BsDropbox(rx.Component):
    library = "react-icons/bs"
    tag = "BsDropbox"


class BsDropletFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsDropletFill"


class BsDropletHalf(rx.Component):
    library = "react-icons/bs"
    tag = "BsDropletHalf"


class BsDroplet(rx.Component):
    library = "react-icons/bs"
    tag = "BsDroplet"


class BsEarFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEarFill"


class BsEar(rx.Component):
    library = "react-icons/bs"
    tag = "BsEar"


class BsEarbuds(rx.Component):
    library = "react-icons/bs"
    tag = "BsEarbuds"


class BsEaselFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEaselFill"


class BsEasel(rx.Component):
    library = "react-icons/bs"
    tag = "BsEasel"


class BsEasel2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEasel2Fill"


class BsEasel2(rx.Component):
    library = "react-icons/bs"
    tag = "BsEasel2"


class BsEasel3Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEasel3Fill"


class BsEasel3(rx.Component):
    library = "react-icons/bs"
    tag = "BsEasel3"


class BsEggFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEggFill"


class BsEggFried(rx.Component):
    library = "react-icons/bs"
    tag = "BsEggFried"


class BsEgg(rx.Component):
    library = "react-icons/bs"
    tag = "BsEgg"


class BsEjectFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEjectFill"


class BsEject(rx.Component):
    library = "react-icons/bs"
    tag = "BsEject"


class BsEmojiAngryFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiAngryFill"


class BsEmojiAngry(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiAngry"


class BsEmojiDizzyFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiDizzyFill"


class BsEmojiDizzy(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiDizzy"


class BsEmojiExpressionlessFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiExpressionlessFill"


class BsEmojiExpressionless(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiExpressionless"


class BsEmojiFrownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiFrownFill"


class BsEmojiFrown(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiFrown"


class BsEmojiHeartEyesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiHeartEyesFill"


class BsEmojiHeartEyes(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiHeartEyes"


class BsEmojiKissFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiKissFill"


class BsEmojiKiss(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiKiss"


class BsEmojiLaughingFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiLaughingFill"


class BsEmojiLaughing(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiLaughing"


class BsEmojiNeutralFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiNeutralFill"


class BsEmojiNeutral(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiNeutral"


class BsEmojiSmileFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiSmileFill"


class BsEmojiSmileUpsideDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiSmileUpsideDownFill"


class BsEmojiSmileUpsideDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiSmileUpsideDown"


class BsEmojiSmile(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiSmile"


class BsEmojiSunglassesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiSunglassesFill"


class BsEmojiSunglasses(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiSunglasses"


class BsEmojiWinkFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiWinkFill"


class BsEmojiWink(rx.Component):
    library = "react-icons/bs"
    tag = "BsEmojiWink"


class BsEnvelopeAtFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeAtFill"


class BsEnvelopeAt(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeAt"


class BsEnvelopeCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeCheckFill"


class BsEnvelopeCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeCheck"


class BsEnvelopeDashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeDashFill"


class BsEnvelopeDash(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeDash"


class BsEnvelopeExclamationFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeExclamationFill"


class BsEnvelopeExclamation(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeExclamation"


class BsEnvelopeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeFill"


class BsEnvelopeHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeHeartFill"


class BsEnvelopeHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeHeart"


class BsEnvelopeOpenFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeOpenFill"


class BsEnvelopeOpenHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeOpenHeartFill"


class BsEnvelopeOpenHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeOpenHeart"


class BsEnvelopeOpen(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeOpen"


class BsEnvelopePaperFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopePaperFill"


class BsEnvelopePaperHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopePaperHeartFill"


class BsEnvelopePaperHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopePaperHeart"


class BsEnvelopePaper(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopePaper"


class BsEnvelopePlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopePlusFill"


class BsEnvelopePlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopePlus"


class BsEnvelopeSlashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeSlashFill"


class BsEnvelopeSlash(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeSlash"


class BsEnvelopeXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeXFill"


class BsEnvelopeX(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelopeX"


class BsEnvelope(rx.Component):
    library = "react-icons/bs"
    tag = "BsEnvelope"


class BsEraserFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEraserFill"


class BsEraser(rx.Component):
    library = "react-icons/bs"
    tag = "BsEraser"


class BsEscape(rx.Component):
    library = "react-icons/bs"
    tag = "BsEscape"


class BsEthernet(rx.Component):
    library = "react-icons/bs"
    tag = "BsEthernet"


class BsEvFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEvFrontFill"


class BsEvFront(rx.Component):
    library = "react-icons/bs"
    tag = "BsEvFront"


class BsEvStationFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEvStationFill"


class BsEvStation(rx.Component):
    library = "react-icons/bs"
    tag = "BsEvStation"


class BsExclamationCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsExclamationCircleFill"


class BsExclamationCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsExclamationCircle"


class BsExclamationDiamondFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsExclamationDiamondFill"


class BsExclamationDiamond(rx.Component):
    library = "react-icons/bs"
    tag = "BsExclamationDiamond"


class BsExclamationLg(rx.Component):
    library = "react-icons/bs"
    tag = "BsExclamationLg"


class BsExclamationOctagonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsExclamationOctagonFill"


class BsExclamationOctagon(rx.Component):
    library = "react-icons/bs"
    tag = "BsExclamationOctagon"


class BsExclamationSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsExclamationSquareFill"


class BsExclamationSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsExclamationSquare"


class BsExclamationTriangleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsExclamationTriangleFill"


class BsExclamationTriangle(rx.Component):
    library = "react-icons/bs"
    tag = "BsExclamationTriangle"


class BsExclamation(rx.Component):
    library = "react-icons/bs"
    tag = "BsExclamation"


class BsExclude(rx.Component):
    library = "react-icons/bs"
    tag = "BsExclude"


class BsExplicitFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsExplicitFill"


class BsExplicit(rx.Component):
    library = "react-icons/bs"
    tag = "BsExplicit"


class BsEyeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEyeFill"


class BsEyeSlashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsEyeSlashFill"


class BsEyeSlash(rx.Component):
    library = "react-icons/bs"
    tag = "BsEyeSlash"


class BsEye(rx.Component):
    library = "react-icons/bs"
    tag = "BsEye"


class BsEyedropper(rx.Component):
    library = "react-icons/bs"
    tag = "BsEyedropper"


class BsEyeglasses(rx.Component):
    library = "react-icons/bs"
    tag = "BsEyeglasses"


class BsFacebook(rx.Component):
    library = "react-icons/bs"
    tag = "BsFacebook"


class BsFan(rx.Component):
    library = "react-icons/bs"
    tag = "BsFan"


class BsFastForwardBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFastForwardBtnFill"


class BsFastForwardBtn(rx.Component):
    library = "react-icons/bs"
    tag = "BsFastForwardBtn"


class BsFastForwardCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFastForwardCircleFill"


class BsFastForwardCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsFastForwardCircle"


class BsFastForwardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFastForwardFill"


class BsFastForward(rx.Component):
    library = "react-icons/bs"
    tag = "BsFastForward"


class BsFileArrowDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileArrowDownFill"


class BsFileArrowDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileArrowDown"


class BsFileArrowUpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileArrowUpFill"


class BsFileArrowUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileArrowUp"


class BsFileBarGraphFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileBarGraphFill"


class BsFileBarGraph(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileBarGraph"


class BsFileBinaryFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileBinaryFill"


class BsFileBinary(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileBinary"


class BsFileBreakFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileBreakFill"


class BsFileBreak(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileBreak"


class BsFileCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileCheckFill"


class BsFileCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileCheck"


class BsFileCodeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileCodeFill"


class BsFileCode(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileCode"


class BsFileDiffFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileDiffFill"


class BsFileDiff(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileDiff"


class BsFileEarmarkArrowDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkArrowDownFill"


class BsFileEarmarkArrowDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkArrowDown"


class BsFileEarmarkArrowUpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkArrowUpFill"


class BsFileEarmarkArrowUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkArrowUp"


class BsFileEarmarkBarGraphFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkBarGraphFill"


class BsFileEarmarkBarGraph(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkBarGraph"


class BsFileEarmarkBinaryFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkBinaryFill"


class BsFileEarmarkBinary(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkBinary"


class BsFileEarmarkBreakFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkBreakFill"


class BsFileEarmarkBreak(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkBreak"


class BsFileEarmarkCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkCheckFill"


class BsFileEarmarkCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkCheck"


class BsFileEarmarkCodeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkCodeFill"


class BsFileEarmarkCode(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkCode"


class BsFileEarmarkDiffFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkDiffFill"


class BsFileEarmarkDiff(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkDiff"


class BsFileEarmarkEaselFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkEaselFill"


class BsFileEarmarkEasel(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkEasel"


class BsFileEarmarkExcelFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkExcelFill"


class BsFileEarmarkExcel(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkExcel"


class BsFileEarmarkFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkFill"


class BsFileEarmarkFontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkFontFill"


class BsFileEarmarkFont(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkFont"


class BsFileEarmarkImageFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkImageFill"


class BsFileEarmarkImage(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkImage"


class BsFileEarmarkLockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkLockFill"


class BsFileEarmarkLock(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkLock"


class BsFileEarmarkLock2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkLock2Fill"


class BsFileEarmarkLock2(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkLock2"


class BsFileEarmarkMedicalFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkMedicalFill"


class BsFileEarmarkMedical(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkMedical"


class BsFileEarmarkMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkMinusFill"


class BsFileEarmarkMinus(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkMinus"


class BsFileEarmarkMusicFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkMusicFill"


class BsFileEarmarkMusic(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkMusic"


class BsFileEarmarkPdfFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkPdfFill"


class BsFileEarmarkPdf(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkPdf"


class BsFileEarmarkPersonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkPersonFill"


class BsFileEarmarkPerson(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkPerson"


class BsFileEarmarkPlayFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkPlayFill"


class BsFileEarmarkPlay(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkPlay"


class BsFileEarmarkPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkPlusFill"


class BsFileEarmarkPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkPlus"


class BsFileEarmarkPostFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkPostFill"


class BsFileEarmarkPost(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkPost"


class BsFileEarmarkPptFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkPptFill"


class BsFileEarmarkPpt(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkPpt"


class BsFileEarmarkRichtextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkRichtextFill"


class BsFileEarmarkRichtext(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkRichtext"


class BsFileEarmarkRuledFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkRuledFill"


class BsFileEarmarkRuled(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkRuled"


class BsFileEarmarkSlidesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkSlidesFill"


class BsFileEarmarkSlides(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkSlides"


class BsFileEarmarkSpreadsheetFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkSpreadsheetFill"


class BsFileEarmarkSpreadsheet(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkSpreadsheet"


class BsFileEarmarkTextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkTextFill"


class BsFileEarmarkText(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkText"


class BsFileEarmarkWordFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkWordFill"


class BsFileEarmarkWord(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkWord"


class BsFileEarmarkXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkXFill"


class BsFileEarmarkX(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkX"


class BsFileEarmarkZipFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkZipFill"


class BsFileEarmarkZip(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmarkZip"


class BsFileEarmark(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEarmark"


class BsFileEaselFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEaselFill"


class BsFileEasel(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileEasel"


class BsFileExcelFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileExcelFill"


class BsFileExcel(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileExcel"


class BsFileFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileFill"


class BsFileFontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileFontFill"


class BsFileFont(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileFont"


class BsFileImageFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileImageFill"


class BsFileImage(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileImage"


class BsFileLockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileLockFill"


class BsFileLock(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileLock"


class BsFileLock2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileLock2Fill"


class BsFileLock2(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileLock2"


class BsFileMedicalFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileMedicalFill"


class BsFileMedical(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileMedical"


class BsFileMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileMinusFill"


class BsFileMinus(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileMinus"


class BsFileMusicFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileMusicFill"


class BsFileMusic(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileMusic"


class BsFilePdfFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilePdfFill"


class BsFilePdf(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilePdf"


class BsFilePersonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilePersonFill"


class BsFilePerson(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilePerson"


class BsFilePlayFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilePlayFill"


class BsFilePlay(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilePlay"


class BsFilePlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilePlusFill"


class BsFilePlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilePlus"


class BsFilePostFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilePostFill"


class BsFilePost(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilePost"


class BsFilePptFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilePptFill"


class BsFilePpt(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilePpt"


class BsFileRichtextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileRichtextFill"


class BsFileRichtext(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileRichtext"


class BsFileRuledFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileRuledFill"


class BsFileRuled(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileRuled"


class BsFileSlidesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileSlidesFill"


class BsFileSlides(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileSlides"


class BsFileSpreadsheetFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileSpreadsheetFill"


class BsFileSpreadsheet(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileSpreadsheet"


class BsFileTextFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileTextFill"


class BsFileText(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileText"


class BsFileWordFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileWordFill"


class BsFileWord(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileWord"


class BsFileXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileXFill"


class BsFileX(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileX"


class BsFileZipFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileZipFill"


class BsFileZip(rx.Component):
    library = "react-icons/bs"
    tag = "BsFileZip"


class BsFile(rx.Component):
    library = "react-icons/bs"
    tag = "BsFile"


class BsFilesAlt(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilesAlt"


class BsFiles(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiles"


class BsFiletypeAac(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeAac"


class BsFiletypeAi(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeAi"


class BsFiletypeBmp(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeBmp"


class BsFiletypeCs(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeCs"


class BsFiletypeCss(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeCss"


class BsFiletypeCsv(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeCsv"


class BsFiletypeDoc(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeDoc"


class BsFiletypeDocx(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeDocx"


class BsFiletypeExe(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeExe"


class BsFiletypeGif(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeGif"


class BsFiletypeHeic(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeHeic"


class BsFiletypeHtml(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeHtml"


class BsFiletypeJava(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeJava"


class BsFiletypeJpg(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeJpg"


class BsFiletypeJs(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeJs"


class BsFiletypeJson(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeJson"


class BsFiletypeJsx(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeJsx"


class BsFiletypeKey(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeKey"


class BsFiletypeM4P(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeM4P"


class BsFiletypeMd(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeMd"


class BsFiletypeMdx(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeMdx"


class BsFiletypeMov(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeMov"


class BsFiletypeMp3(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeMp3"


class BsFiletypeMp4(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeMp4"


class BsFiletypeOtf(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeOtf"


class BsFiletypePdf(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypePdf"


class BsFiletypePhp(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypePhp"


class BsFiletypePng(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypePng"


class BsFiletypePpt(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypePpt"


class BsFiletypePptx(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypePptx"


class BsFiletypePsd(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypePsd"


class BsFiletypePy(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypePy"


class BsFiletypeRaw(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeRaw"


class BsFiletypeRb(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeRb"


class BsFiletypeSass(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeSass"


class BsFiletypeScss(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeScss"


class BsFiletypeSh(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeSh"


class BsFiletypeSql(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeSql"


class BsFiletypeSvg(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeSvg"


class BsFiletypeTiff(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeTiff"


class BsFiletypeTsx(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeTsx"


class BsFiletypeTtf(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeTtf"


class BsFiletypeTxt(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeTxt"


class BsFiletypeWav(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeWav"


class BsFiletypeWoff(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeWoff"


class BsFiletypeXls(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeXls"


class BsFiletypeXlsx(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeXlsx"


class BsFiletypeXml(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeXml"


class BsFiletypeYml(rx.Component):
    library = "react-icons/bs"
    tag = "BsFiletypeYml"


class BsFilm(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilm"


class BsFilterCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilterCircleFill"


class BsFilterCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilterCircle"


class BsFilterLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilterLeft"


class BsFilterRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilterRight"


class BsFilterSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilterSquareFill"


class BsFilterSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilterSquare"


class BsFilter(rx.Component):
    library = "react-icons/bs"
    tag = "BsFilter"


class BsFingerprint(rx.Component):
    library = "react-icons/bs"
    tag = "BsFingerprint"


class BsFire(rx.Component):
    library = "react-icons/bs"
    tag = "BsFire"


class BsFlagFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFlagFill"


class BsFlag(rx.Component):
    library = "react-icons/bs"
    tag = "BsFlag"


class BsFlower1(rx.Component):
    library = "react-icons/bs"
    tag = "BsFlower1"


class BsFlower2(rx.Component):
    library = "react-icons/bs"
    tag = "BsFlower2"


class BsFlower3(rx.Component):
    library = "react-icons/bs"
    tag = "BsFlower3"


class BsFolderCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsFolderCheck"


class BsFolderFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFolderFill"


class BsFolderMinus(rx.Component):
    library = "react-icons/bs"
    tag = "BsFolderMinus"


class BsFolderPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsFolderPlus"


class BsFolderSymlinkFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFolderSymlinkFill"


class BsFolderSymlink(rx.Component):
    library = "react-icons/bs"
    tag = "BsFolderSymlink"


class BsFolderX(rx.Component):
    library = "react-icons/bs"
    tag = "BsFolderX"


class BsFolder(rx.Component):
    library = "react-icons/bs"
    tag = "BsFolder"


class BsFolder2Open(rx.Component):
    library = "react-icons/bs"
    tag = "BsFolder2Open"


class BsFolder2(rx.Component):
    library = "react-icons/bs"
    tag = "BsFolder2"


class BsFonts(rx.Component):
    library = "react-icons/bs"
    tag = "BsFonts"


class BsForwardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsForwardFill"


class BsForward(rx.Component):
    library = "react-icons/bs"
    tag = "BsForward"


class BsFront(rx.Component):
    library = "react-icons/bs"
    tag = "BsFront"


class BsFuelPumpDieselFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFuelPumpDieselFill"


class BsFuelPumpDiesel(rx.Component):
    library = "react-icons/bs"
    tag = "BsFuelPumpDiesel"


class BsFuelPumpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFuelPumpFill"


class BsFuelPump(rx.Component):
    library = "react-icons/bs"
    tag = "BsFuelPump"


class BsFullscreenExit(rx.Component):
    library = "react-icons/bs"
    tag = "BsFullscreenExit"


class BsFullscreen(rx.Component):
    library = "react-icons/bs"
    tag = "BsFullscreen"


class BsFunnelFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsFunnelFill"


class BsFunnel(rx.Component):
    library = "react-icons/bs"
    tag = "BsFunnel"


class BsGearFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsGearFill"


class BsGearWideConnected(rx.Component):
    library = "react-icons/bs"
    tag = "BsGearWideConnected"


class BsGearWide(rx.Component):
    library = "react-icons/bs"
    tag = "BsGearWide"


class BsGear(rx.Component):
    library = "react-icons/bs"
    tag = "BsGear"


class BsGem(rx.Component):
    library = "react-icons/bs"
    tag = "BsGem"


class BsGenderAmbiguous(rx.Component):
    library = "react-icons/bs"
    tag = "BsGenderAmbiguous"


class BsGenderFemale(rx.Component):
    library = "react-icons/bs"
    tag = "BsGenderFemale"


class BsGenderMale(rx.Component):
    library = "react-icons/bs"
    tag = "BsGenderMale"


class BsGenderTrans(rx.Component):
    library = "react-icons/bs"
    tag = "BsGenderTrans"


class BsGeoAltFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsGeoAltFill"


class BsGeoAlt(rx.Component):
    library = "react-icons/bs"
    tag = "BsGeoAlt"


class BsGeoFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsGeoFill"


class BsGeo(rx.Component):
    library = "react-icons/bs"
    tag = "BsGeo"


class BsGiftFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsGiftFill"


class BsGift(rx.Component):
    library = "react-icons/bs"
    tag = "BsGift"


class BsGit(rx.Component):
    library = "react-icons/bs"
    tag = "BsGit"


class BsGithub(rx.Component):
    library = "react-icons/bs"
    tag = "BsGithub"


class BsGlobeAmericas(rx.Component):
    library = "react-icons/bs"
    tag = "BsGlobeAmericas"


class BsGlobeAsiaAustralia(rx.Component):
    library = "react-icons/bs"
    tag = "BsGlobeAsiaAustralia"


class BsGlobeCentralSouthAsia(rx.Component):
    library = "react-icons/bs"
    tag = "BsGlobeCentralSouthAsia"


class BsGlobeEuropeAfrica(rx.Component):
    library = "react-icons/bs"
    tag = "BsGlobeEuropeAfrica"


class BsGlobe(rx.Component):
    library = "react-icons/bs"
    tag = "BsGlobe"


class BsGlobe2(rx.Component):
    library = "react-icons/bs"
    tag = "BsGlobe2"


class BsGooglePlay(rx.Component):
    library = "react-icons/bs"
    tag = "BsGooglePlay"


class BsGoogle(rx.Component):
    library = "react-icons/bs"
    tag = "BsGoogle"


class BsGpuCard(rx.Component):
    library = "react-icons/bs"
    tag = "BsGpuCard"


class BsGraphDownArrow(rx.Component):
    library = "react-icons/bs"
    tag = "BsGraphDownArrow"


class BsGraphDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsGraphDown"


class BsGraphUpArrow(rx.Component):
    library = "react-icons/bs"
    tag = "BsGraphUpArrow"


class BsGraphUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsGraphUp"


class BsGrid1X2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsGrid1X2Fill"


class BsGrid1X2(rx.Component):
    library = "react-icons/bs"
    tag = "BsGrid1X2"


class BsGrid3X2GapFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsGrid3X2GapFill"


class BsGrid3X2Gap(rx.Component):
    library = "react-icons/bs"
    tag = "BsGrid3X2Gap"


class BsGrid3X2(rx.Component):
    library = "react-icons/bs"
    tag = "BsGrid3X2"


class BsGrid3X3GapFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsGrid3X3GapFill"


class BsGrid3X3Gap(rx.Component):
    library = "react-icons/bs"
    tag = "BsGrid3X3Gap"


class BsGrid3X3(rx.Component):
    library = "react-icons/bs"
    tag = "BsGrid3X3"


class BsGridFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsGridFill"


class BsGrid(rx.Component):
    library = "react-icons/bs"
    tag = "BsGrid"


class BsGripHorizontal(rx.Component):
    library = "react-icons/bs"
    tag = "BsGripHorizontal"


class BsGripVertical(rx.Component):
    library = "react-icons/bs"
    tag = "BsGripVertical"


class BsHCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHCircleFill"


class BsHCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsHCircle"


class BsHSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHSquareFill"


class BsHSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsHSquare"


class BsHammer(rx.Component):
    library = "react-icons/bs"
    tag = "BsHammer"


class BsHandIndexFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHandIndexFill"


class BsHandIndexThumbFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHandIndexThumbFill"


class BsHandIndexThumb(rx.Component):
    library = "react-icons/bs"
    tag = "BsHandIndexThumb"


class BsHandIndex(rx.Component):
    library = "react-icons/bs"
    tag = "BsHandIndex"


class BsHandThumbsDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHandThumbsDownFill"


class BsHandThumbsDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsHandThumbsDown"


class BsHandThumbsUpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHandThumbsUpFill"


class BsHandThumbsUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsHandThumbsUp"


class BsHandbagFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHandbagFill"


class BsHandbag(rx.Component):
    library = "react-icons/bs"
    tag = "BsHandbag"


class BsHash(rx.Component):
    library = "react-icons/bs"
    tag = "BsHash"


class BsHddFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHddFill"


class BsHddNetworkFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHddNetworkFill"


class BsHddNetwork(rx.Component):
    library = "react-icons/bs"
    tag = "BsHddNetwork"


class BsHddRackFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHddRackFill"


class BsHddRack(rx.Component):
    library = "react-icons/bs"
    tag = "BsHddRack"


class BsHddStackFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHddStackFill"


class BsHddStack(rx.Component):
    library = "react-icons/bs"
    tag = "BsHddStack"


class BsHdd(rx.Component):
    library = "react-icons/bs"
    tag = "BsHdd"


class BsHdmiFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHdmiFill"


class BsHdmi(rx.Component):
    library = "react-icons/bs"
    tag = "BsHdmi"


class BsHeadphones(rx.Component):
    library = "react-icons/bs"
    tag = "BsHeadphones"


class BsHeadsetVr(rx.Component):
    library = "react-icons/bs"
    tag = "BsHeadsetVr"


class BsHeadset(rx.Component):
    library = "react-icons/bs"
    tag = "BsHeadset"


class BsHeartArrow(rx.Component):
    library = "react-icons/bs"
    tag = "BsHeartArrow"


class BsHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHeartFill"


class BsHeartHalf(rx.Component):
    library = "react-icons/bs"
    tag = "BsHeartHalf"


class BsHeartPulseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHeartPulseFill"


class BsHeartPulse(rx.Component):
    library = "react-icons/bs"
    tag = "BsHeartPulse"


class BsHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsHeart"


class BsHeartbreakFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHeartbreakFill"


class BsHeartbreak(rx.Component):
    library = "react-icons/bs"
    tag = "BsHeartbreak"


class BsHearts(rx.Component):
    library = "react-icons/bs"
    tag = "BsHearts"


class BsHeptagonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHeptagonFill"


class BsHeptagonHalf(rx.Component):
    library = "react-icons/bs"
    tag = "BsHeptagonHalf"


class BsHeptagon(rx.Component):
    library = "react-icons/bs"
    tag = "BsHeptagon"


class BsHexagonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHexagonFill"


class BsHexagonHalf(rx.Component):
    library = "react-icons/bs"
    tag = "BsHexagonHalf"


class BsHexagon(rx.Component):
    library = "react-icons/bs"
    tag = "BsHexagon"


class BsHospitalFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHospitalFill"


class BsHospital(rx.Component):
    library = "react-icons/bs"
    tag = "BsHospital"


class BsHourglassBottom(rx.Component):
    library = "react-icons/bs"
    tag = "BsHourglassBottom"


class BsHourglassSplit(rx.Component):
    library = "react-icons/bs"
    tag = "BsHourglassSplit"


class BsHourglassTop(rx.Component):
    library = "react-icons/bs"
    tag = "BsHourglassTop"


class BsHourglass(rx.Component):
    library = "react-icons/bs"
    tag = "BsHourglass"


class BsHouseAddFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseAddFill"


class BsHouseAdd(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseAdd"


class BsHouseCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseCheckFill"


class BsHouseCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseCheck"


class BsHouseDashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseDashFill"


class BsHouseDash(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseDash"


class BsHouseDoorFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseDoorFill"


class BsHouseDoor(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseDoor"


class BsHouseDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseDownFill"


class BsHouseDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseDown"


class BsHouseExclamationFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseExclamationFill"


class BsHouseExclamation(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseExclamation"


class BsHouseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseFill"


class BsHouseGearFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseGearFill"


class BsHouseGear(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseGear"


class BsHouseHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseHeartFill"


class BsHouseHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseHeart"


class BsHouseLockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseLockFill"


class BsHouseLock(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseLock"


class BsHouseSlashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseSlashFill"


class BsHouseSlash(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseSlash"


class BsHouseUpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseUpFill"


class BsHouseUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseUp"


class BsHouseXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseXFill"


class BsHouseX(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouseX"


class BsHouse(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouse"


class BsHousesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsHousesFill"


class BsHouses(rx.Component):
    library = "react-icons/bs"
    tag = "BsHouses"


class BsHr(rx.Component):
    library = "react-icons/bs"
    tag = "BsHr"


class BsHurricane(rx.Component):
    library = "react-icons/bs"
    tag = "BsHurricane"


class BsHypnotize(rx.Component):
    library = "react-icons/bs"
    tag = "BsHypnotize"


class BsImageAlt(rx.Component):
    library = "react-icons/bs"
    tag = "BsImageAlt"


class BsImageFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsImageFill"


class BsImage(rx.Component):
    library = "react-icons/bs"
    tag = "BsImage"


class BsImages(rx.Component):
    library = "react-icons/bs"
    tag = "BsImages"


class BsInboxFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsInboxFill"


class BsInbox(rx.Component):
    library = "react-icons/bs"
    tag = "BsInbox"


class BsInboxesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsInboxesFill"


class BsInboxes(rx.Component):
    library = "react-icons/bs"
    tag = "BsInboxes"


class BsIncognito(rx.Component):
    library = "react-icons/bs"
    tag = "BsIncognito"


class BsIndent(rx.Component):
    library = "react-icons/bs"
    tag = "BsIndent"


class BsInfinity(rx.Component):
    library = "react-icons/bs"
    tag = "BsInfinity"


class BsInfoCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsInfoCircleFill"


class BsInfoCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsInfoCircle"


class BsInfoLg(rx.Component):
    library = "react-icons/bs"
    tag = "BsInfoLg"


class BsInfoSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsInfoSquareFill"


class BsInfoSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsInfoSquare"


class BsInfo(rx.Component):
    library = "react-icons/bs"
    tag = "BsInfo"


class BsInputCursorText(rx.Component):
    library = "react-icons/bs"
    tag = "BsInputCursorText"


class BsInputCursor(rx.Component):
    library = "react-icons/bs"
    tag = "BsInputCursor"


class BsInstagram(rx.Component):
    library = "react-icons/bs"
    tag = "BsInstagram"


class BsIntersect(rx.Component):
    library = "react-icons/bs"
    tag = "BsIntersect"


class BsJournalAlbum(rx.Component):
    library = "react-icons/bs"
    tag = "BsJournalAlbum"


class BsJournalArrowDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsJournalArrowDown"


class BsJournalArrowUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsJournalArrowUp"


class BsJournalBookmarkFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsJournalBookmarkFill"


class BsJournalBookmark(rx.Component):
    library = "react-icons/bs"
    tag = "BsJournalBookmark"


class BsJournalCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsJournalCheck"


class BsJournalCode(rx.Component):
    library = "react-icons/bs"
    tag = "BsJournalCode"


class BsJournalMedical(rx.Component):
    library = "react-icons/bs"
    tag = "BsJournalMedical"


class BsJournalMinus(rx.Component):
    library = "react-icons/bs"
    tag = "BsJournalMinus"


class BsJournalPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsJournalPlus"


class BsJournalRichtext(rx.Component):
    library = "react-icons/bs"
    tag = "BsJournalRichtext"


class BsJournalText(rx.Component):
    library = "react-icons/bs"
    tag = "BsJournalText"


class BsJournalX(rx.Component):
    library = "react-icons/bs"
    tag = "BsJournalX"


class BsJournal(rx.Component):
    library = "react-icons/bs"
    tag = "BsJournal"


class BsJournals(rx.Component):
    library = "react-icons/bs"
    tag = "BsJournals"


class BsJoystick(rx.Component):
    library = "react-icons/bs"
    tag = "BsJoystick"


class BsJustifyLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsJustifyLeft"


class BsJustifyRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsJustifyRight"


class BsJustify(rx.Component):
    library = "react-icons/bs"
    tag = "BsJustify"


class BsKanbanFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsKanbanFill"


class BsKanban(rx.Component):
    library = "react-icons/bs"
    tag = "BsKanban"


class BsKeyFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsKeyFill"


class BsKey(rx.Component):
    library = "react-icons/bs"
    tag = "BsKey"


class BsKeyboardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsKeyboardFill"


class BsKeyboard(rx.Component):
    library = "react-icons/bs"
    tag = "BsKeyboard"


class BsLadder(rx.Component):
    library = "react-icons/bs"
    tag = "BsLadder"


class BsLampFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsLampFill"


class BsLamp(rx.Component):
    library = "react-icons/bs"
    tag = "BsLamp"


class BsLaptopFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsLaptopFill"


class BsLaptop(rx.Component):
    library = "react-icons/bs"
    tag = "BsLaptop"


class BsLayerBackward(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayerBackward"


class BsLayerForward(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayerForward"


class BsLayersFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayersFill"


class BsLayersHalf(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayersHalf"


class BsLayers(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayers"


class BsLayoutSidebarInsetReverse(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayoutSidebarInsetReverse"


class BsLayoutSidebarInset(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayoutSidebarInset"


class BsLayoutSidebarReverse(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayoutSidebarReverse"


class BsLayoutSidebar(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayoutSidebar"


class BsLayoutSplit(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayoutSplit"


class BsLayoutTextSidebarReverse(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayoutTextSidebarReverse"


class BsLayoutTextSidebar(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayoutTextSidebar"


class BsLayoutTextWindowReverse(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayoutTextWindowReverse"


class BsLayoutTextWindow(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayoutTextWindow"


class BsLayoutThreeColumns(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayoutThreeColumns"


class BsLayoutWtf(rx.Component):
    library = "react-icons/bs"
    tag = "BsLayoutWtf"


class BsLifePreserver(rx.Component):
    library = "react-icons/bs"
    tag = "BsLifePreserver"


class BsLightbulbFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsLightbulbFill"


class BsLightbulbOffFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsLightbulbOffFill"


class BsLightbulbOff(rx.Component):
    library = "react-icons/bs"
    tag = "BsLightbulbOff"


class BsLightbulb(rx.Component):
    library = "react-icons/bs"
    tag = "BsLightbulb"


class BsLightningChargeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsLightningChargeFill"


class BsLightningCharge(rx.Component):
    library = "react-icons/bs"
    tag = "BsLightningCharge"


class BsLightningFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsLightningFill"


class BsLightning(rx.Component):
    library = "react-icons/bs"
    tag = "BsLightning"


class BsLine(rx.Component):
    library = "react-icons/bs"
    tag = "BsLine"


class BsLink45Deg(rx.Component):
    library = "react-icons/bs"
    tag = "BsLink45Deg"


class BsLink(rx.Component):
    library = "react-icons/bs"
    tag = "BsLink"


class BsLinkedin(rx.Component):
    library = "react-icons/bs"
    tag = "BsLinkedin"


class BsListCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsListCheck"


class BsListColumnsReverse(rx.Component):
    library = "react-icons/bs"
    tag = "BsListColumnsReverse"


class BsListColumns(rx.Component):
    library = "react-icons/bs"
    tag = "BsListColumns"


class BsListNested(rx.Component):
    library = "react-icons/bs"
    tag = "BsListNested"


class BsListOl(rx.Component):
    library = "react-icons/bs"
    tag = "BsListOl"


class BsListStars(rx.Component):
    library = "react-icons/bs"
    tag = "BsListStars"


class BsListTask(rx.Component):
    library = "react-icons/bs"
    tag = "BsListTask"


class BsListUl(rx.Component):
    library = "react-icons/bs"
    tag = "BsListUl"


class BsList(rx.Component):
    library = "react-icons/bs"
    tag = "BsList"


class BsLockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsLockFill"


class BsLock(rx.Component):
    library = "react-icons/bs"
    tag = "BsLock"


class BsLungsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsLungsFill"


class BsLungs(rx.Component):
    library = "react-icons/bs"
    tag = "BsLungs"


class BsMagic(rx.Component):
    library = "react-icons/bs"
    tag = "BsMagic"


class BsMagnetFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMagnetFill"


class BsMagnet(rx.Component):
    library = "react-icons/bs"
    tag = "BsMagnet"


class BsMailbox(rx.Component):
    library = "react-icons/bs"
    tag = "BsMailbox"


class BsMailbox2(rx.Component):
    library = "react-icons/bs"
    tag = "BsMailbox2"


class BsMapFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMapFill"


class BsMap(rx.Component):
    library = "react-icons/bs"
    tag = "BsMap"


class BsMarkdownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMarkdownFill"


class BsMarkdown(rx.Component):
    library = "react-icons/bs"
    tag = "BsMarkdown"


class BsMask(rx.Component):
    library = "react-icons/bs"
    tag = "BsMask"


class BsMastodon(rx.Component):
    library = "react-icons/bs"
    tag = "BsMastodon"


class BsMedium(rx.Component):
    library = "react-icons/bs"
    tag = "BsMedium"


class BsMegaphoneFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMegaphoneFill"


class BsMegaphone(rx.Component):
    library = "react-icons/bs"
    tag = "BsMegaphone"


class BsMemory(rx.Component):
    library = "react-icons/bs"
    tag = "BsMemory"


class BsMenuAppFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMenuAppFill"


class BsMenuApp(rx.Component):
    library = "react-icons/bs"
    tag = "BsMenuApp"


class BsMenuButtonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMenuButtonFill"


class BsMenuButtonWideFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMenuButtonWideFill"


class BsMenuButtonWide(rx.Component):
    library = "react-icons/bs"
    tag = "BsMenuButtonWide"


class BsMenuButton(rx.Component):
    library = "react-icons/bs"
    tag = "BsMenuButton"


class BsMenuDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsMenuDown"


class BsMenuUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsMenuUp"


class BsMessenger(rx.Component):
    library = "react-icons/bs"
    tag = "BsMessenger"


class BsMeta(rx.Component):
    library = "react-icons/bs"
    tag = "BsMeta"


class BsMicFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMicFill"


class BsMicMuteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMicMuteFill"


class BsMicMute(rx.Component):
    library = "react-icons/bs"
    tag = "BsMicMute"


class BsMic(rx.Component):
    library = "react-icons/bs"
    tag = "BsMic"


class BsMicrosoftTeams(rx.Component):
    library = "react-icons/bs"
    tag = "BsMicrosoftTeams"


class BsMicrosoft(rx.Component):
    library = "react-icons/bs"
    tag = "BsMicrosoft"


class BsMinecartLoaded(rx.Component):
    library = "react-icons/bs"
    tag = "BsMinecartLoaded"


class BsMinecart(rx.Component):
    library = "react-icons/bs"
    tag = "BsMinecart"


class BsModemFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsModemFill"


class BsModem(rx.Component):
    library = "react-icons/bs"
    tag = "BsModem"


class BsMoisture(rx.Component):
    library = "react-icons/bs"
    tag = "BsMoisture"


class BsMoonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMoonFill"


class BsMoonStarsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMoonStarsFill"


class BsMoonStars(rx.Component):
    library = "react-icons/bs"
    tag = "BsMoonStars"


class BsMoon(rx.Component):
    library = "react-icons/bs"
    tag = "BsMoon"


class BsMortarboardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMortarboardFill"


class BsMortarboard(rx.Component):
    library = "react-icons/bs"
    tag = "BsMortarboard"


class BsMotherboardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMotherboardFill"


class BsMotherboard(rx.Component):
    library = "react-icons/bs"
    tag = "BsMotherboard"


class BsMouseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMouseFill"


class BsMouse(rx.Component):
    library = "react-icons/bs"
    tag = "BsMouse"


class BsMouse2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMouse2Fill"


class BsMouse2(rx.Component):
    library = "react-icons/bs"
    tag = "BsMouse2"


class BsMouse3Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMouse3Fill"


class BsMouse3(rx.Component):
    library = "react-icons/bs"
    tag = "BsMouse3"


class BsMusicNoteBeamed(rx.Component):
    library = "react-icons/bs"
    tag = "BsMusicNoteBeamed"


class BsMusicNoteList(rx.Component):
    library = "react-icons/bs"
    tag = "BsMusicNoteList"


class BsMusicNote(rx.Component):
    library = "react-icons/bs"
    tag = "BsMusicNote"


class BsMusicPlayerFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsMusicPlayerFill"


class BsMusicPlayer(rx.Component):
    library = "react-icons/bs"
    tag = "BsMusicPlayer"


class BsNewspaper(rx.Component):
    library = "react-icons/bs"
    tag = "BsNewspaper"


class BsNintendoSwitch(rx.Component):
    library = "react-icons/bs"
    tag = "BsNintendoSwitch"


class BsNodeMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsNodeMinusFill"


class BsNodeMinus(rx.Component):
    library = "react-icons/bs"
    tag = "BsNodeMinus"


class BsNodePlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsNodePlusFill"


class BsNodePlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsNodePlus"


class BsNutFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsNutFill"


class BsNut(rx.Component):
    library = "react-icons/bs"
    tag = "BsNut"


class BsNvidia(rx.Component):
    library = "react-icons/bs"
    tag = "BsNvidia"


class BsOctagonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsOctagonFill"


class BsOctagonHalf(rx.Component):
    library = "react-icons/bs"
    tag = "BsOctagonHalf"


class BsOctagon(rx.Component):
    library = "react-icons/bs"
    tag = "BsOctagon"


class BsOpticalAudioFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsOpticalAudioFill"


class BsOpticalAudio(rx.Component):
    library = "react-icons/bs"
    tag = "BsOpticalAudio"


class BsOption(rx.Component):
    library = "react-icons/bs"
    tag = "BsOption"


class BsOutlet(rx.Component):
    library = "react-icons/bs"
    tag = "BsOutlet"


class BsPCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPCircleFill"


class BsPCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsPCircle"


class BsPSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPSquareFill"


class BsPSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsPSquare"


class BsPaintBucket(rx.Component):
    library = "react-icons/bs"
    tag = "BsPaintBucket"


class BsPaletteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPaletteFill"


class BsPalette(rx.Component):
    library = "react-icons/bs"
    tag = "BsPalette"


class BsPalette2(rx.Component):
    library = "react-icons/bs"
    tag = "BsPalette2"


class BsPaperclip(rx.Component):
    library = "react-icons/bs"
    tag = "BsPaperclip"


class BsParagraph(rx.Component):
    library = "react-icons/bs"
    tag = "BsParagraph"


class BsPassFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPassFill"


class BsPass(rx.Component):
    library = "react-icons/bs"
    tag = "BsPass"


class BsPatchCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPatchCheckFill"


class BsPatchCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsPatchCheck"


class BsPatchExclamationFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPatchExclamationFill"


class BsPatchExclamation(rx.Component):
    library = "react-icons/bs"
    tag = "BsPatchExclamation"


class BsPatchMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPatchMinusFill"


class BsPatchMinus(rx.Component):
    library = "react-icons/bs"
    tag = "BsPatchMinus"


class BsPatchPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPatchPlusFill"


class BsPatchPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsPatchPlus"


class BsPatchQuestionFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPatchQuestionFill"


class BsPatchQuestion(rx.Component):
    library = "react-icons/bs"
    tag = "BsPatchQuestion"


class BsPauseBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPauseBtnFill"


class BsPauseBtn(rx.Component):
    library = "react-icons/bs"
    tag = "BsPauseBtn"


class BsPauseCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPauseCircleFill"


class BsPauseCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsPauseCircle"


class BsPauseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPauseFill"


class BsPause(rx.Component):
    library = "react-icons/bs"
    tag = "BsPause"


class BsPaypal(rx.Component):
    library = "react-icons/bs"
    tag = "BsPaypal"


class BsPcDisplayHorizontal(rx.Component):
    library = "react-icons/bs"
    tag = "BsPcDisplayHorizontal"


class BsPcDisplay(rx.Component):
    library = "react-icons/bs"
    tag = "BsPcDisplay"


class BsPcHorizontal(rx.Component):
    library = "react-icons/bs"
    tag = "BsPcHorizontal"


class BsPc(rx.Component):
    library = "react-icons/bs"
    tag = "BsPc"


class BsPciCard(rx.Component):
    library = "react-icons/bs"
    tag = "BsPciCard"


class BsPeaceFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPeaceFill"


class BsPeace(rx.Component):
    library = "react-icons/bs"
    tag = "BsPeace"


class BsPenFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPenFill"


class BsPen(rx.Component):
    library = "react-icons/bs"
    tag = "BsPen"


class BsPencilFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPencilFill"


class BsPencilSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsPencilSquare"


class BsPencil(rx.Component):
    library = "react-icons/bs"
    tag = "BsPencil"


class BsPentagonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPentagonFill"


class BsPentagonHalf(rx.Component):
    library = "react-icons/bs"
    tag = "BsPentagonHalf"


class BsPentagon(rx.Component):
    library = "react-icons/bs"
    tag = "BsPentagon"


class BsPeopleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPeopleFill"


class BsPeople(rx.Component):
    library = "react-icons/bs"
    tag = "BsPeople"


class BsPercent(rx.Component):
    library = "react-icons/bs"
    tag = "BsPercent"


class BsPersonAdd(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonAdd"


class BsPersonBadgeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonBadgeFill"


class BsPersonBadge(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonBadge"


class BsPersonBoundingBox(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonBoundingBox"


class BsPersonCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonCheckFill"


class BsPersonCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonCheck"


class BsPersonCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonCircle"


class BsPersonDashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonDashFill"


class BsPersonDash(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonDash"


class BsPersonDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonDown"


class BsPersonExclamation(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonExclamation"


class BsPersonFillAdd(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonFillAdd"


class BsPersonFillCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonFillCheck"


class BsPersonFillDash(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonFillDash"


class BsPersonFillDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonFillDown"


class BsPersonFillExclamation(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonFillExclamation"


class BsPersonFillGear(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonFillGear"


class BsPersonFillLock(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonFillLock"


class BsPersonFillSlash(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonFillSlash"


class BsPersonFillUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonFillUp"


class BsPersonFillX(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonFillX"


class BsPersonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonFill"


class BsPersonGear(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonGear"


class BsPersonHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonHeart"


class BsPersonHearts(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonHearts"


class BsPersonLinesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonLinesFill"


class BsPersonLock(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonLock"


class BsPersonPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonPlusFill"


class BsPersonPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonPlus"


class BsPersonRolodex(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonRolodex"


class BsPersonSlash(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonSlash"


class BsPersonSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonSquare"


class BsPersonUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonUp"


class BsPersonVcardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonVcardFill"


class BsPersonVcard(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonVcard"


class BsPersonVideo(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonVideo"


class BsPersonVideo2(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonVideo2"


class BsPersonVideo3(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonVideo3"


class BsPersonWorkspace(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonWorkspace"


class BsPersonXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonXFill"


class BsPersonX(rx.Component):
    library = "react-icons/bs"
    tag = "BsPersonX"


class BsPerson(rx.Component):
    library = "react-icons/bs"
    tag = "BsPerson"


class BsPhoneFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPhoneFill"


class BsPhoneFlip(rx.Component):
    library = "react-icons/bs"
    tag = "BsPhoneFlip"


class BsPhoneLandscapeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPhoneLandscapeFill"


class BsPhoneLandscape(rx.Component):
    library = "react-icons/bs"
    tag = "BsPhoneLandscape"


class BsPhoneVibrateFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPhoneVibrateFill"


class BsPhoneVibrate(rx.Component):
    library = "react-icons/bs"
    tag = "BsPhoneVibrate"


class BsPhone(rx.Component):
    library = "react-icons/bs"
    tag = "BsPhone"


class BsPieChartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPieChartFill"


class BsPieChart(rx.Component):
    library = "react-icons/bs"
    tag = "BsPieChart"


class BsPiggyBankFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPiggyBankFill"


class BsPiggyBank(rx.Component):
    library = "react-icons/bs"
    tag = "BsPiggyBank"


class BsPinAngleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPinAngleFill"


class BsPinAngle(rx.Component):
    library = "react-icons/bs"
    tag = "BsPinAngle"


class BsPinFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPinFill"


class BsPinMapFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPinMapFill"


class BsPinMap(rx.Component):
    library = "react-icons/bs"
    tag = "BsPinMap"


class BsPin(rx.Component):
    library = "react-icons/bs"
    tag = "BsPin"


class BsPinterest(rx.Component):
    library = "react-icons/bs"
    tag = "BsPinterest"


class BsPipFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPipFill"


class BsPip(rx.Component):
    library = "react-icons/bs"
    tag = "BsPip"


class BsPlayBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlayBtnFill"


class BsPlayBtn(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlayBtn"


class BsPlayCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlayCircleFill"


class BsPlayCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlayCircle"


class BsPlayFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlayFill"


class BsPlay(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlay"


class BsPlaystation(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlaystation"


class BsPlugFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlugFill"


class BsPlug(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlug"


class BsPlugin(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlugin"


class BsPlusCircleDotted(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlusCircleDotted"


class BsPlusCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlusCircleFill"


class BsPlusCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlusCircle"


class BsPlusLg(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlusLg"


class BsPlusSlashMinus(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlusSlashMinus"


class BsPlusSquareDotted(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlusSquareDotted"


class BsPlusSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlusSquareFill"


class BsPlusSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlusSquare"


class BsPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsPlus"


class BsPostageFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPostageFill"


class BsPostageHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPostageHeartFill"


class BsPostageHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsPostageHeart"


class BsPostage(rx.Component):
    library = "react-icons/bs"
    tag = "BsPostage"


class BsPostcardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPostcardFill"


class BsPostcardHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPostcardHeartFill"


class BsPostcardHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsPostcardHeart"


class BsPostcard(rx.Component):
    library = "react-icons/bs"
    tag = "BsPostcard"


class BsPower(rx.Component):
    library = "react-icons/bs"
    tag = "BsPower"


class BsPrescription(rx.Component):
    library = "react-icons/bs"
    tag = "BsPrescription"


class BsPrescription2(rx.Component):
    library = "react-icons/bs"
    tag = "BsPrescription2"


class BsPrinterFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPrinterFill"


class BsPrinter(rx.Component):
    library = "react-icons/bs"
    tag = "BsPrinter"


class BsProjectorFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsProjectorFill"


class BsProjector(rx.Component):
    library = "react-icons/bs"
    tag = "BsProjector"


class BsPuzzleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsPuzzleFill"


class BsPuzzle(rx.Component):
    library = "react-icons/bs"
    tag = "BsPuzzle"


class BsQrCodeScan(rx.Component):
    library = "react-icons/bs"
    tag = "BsQrCodeScan"


class BsQrCode(rx.Component):
    library = "react-icons/bs"
    tag = "BsQrCode"


class BsQuestionCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsQuestionCircleFill"


class BsQuestionCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsQuestionCircle"


class BsQuestionDiamondFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsQuestionDiamondFill"


class BsQuestionDiamond(rx.Component):
    library = "react-icons/bs"
    tag = "BsQuestionDiamond"


class BsQuestionLg(rx.Component):
    library = "react-icons/bs"
    tag = "BsQuestionLg"


class BsQuestionOctagonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsQuestionOctagonFill"


class BsQuestionOctagon(rx.Component):
    library = "react-icons/bs"
    tag = "BsQuestionOctagon"


class BsQuestionSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsQuestionSquareFill"


class BsQuestionSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsQuestionSquare"


class BsQuestion(rx.Component):
    library = "react-icons/bs"
    tag = "BsQuestion"


class BsQuora(rx.Component):
    library = "react-icons/bs"
    tag = "BsQuora"


class BsQuote(rx.Component):
    library = "react-icons/bs"
    tag = "BsQuote"


class BsRCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsRCircleFill"


class BsRCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsRCircle"


class BsRSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsRSquareFill"


class BsRSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsRSquare"


class BsRadioactive(rx.Component):
    library = "react-icons/bs"
    tag = "BsRadioactive"


class BsRainbow(rx.Component):
    library = "react-icons/bs"
    tag = "BsRainbow"


class BsReceiptCutoff(rx.Component):
    library = "react-icons/bs"
    tag = "BsReceiptCutoff"


class BsReceipt(rx.Component):
    library = "react-icons/bs"
    tag = "BsReceipt"


class BsReception0(rx.Component):
    library = "react-icons/bs"
    tag = "BsReception0"


class BsReception1(rx.Component):
    library = "react-icons/bs"
    tag = "BsReception1"


class BsReception2(rx.Component):
    library = "react-icons/bs"
    tag = "BsReception2"


class BsReception3(rx.Component):
    library = "react-icons/bs"
    tag = "BsReception3"


class BsReception4(rx.Component):
    library = "react-icons/bs"
    tag = "BsReception4"


class BsRecordBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsRecordBtnFill"


class BsRecordBtn(rx.Component):
    library = "react-icons/bs"
    tag = "BsRecordBtn"


class BsRecordCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsRecordCircleFill"


class BsRecordCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsRecordCircle"


class BsRecordFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsRecordFill"


class BsRecord(rx.Component):
    library = "react-icons/bs"
    tag = "BsRecord"


class BsRecord2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsRecord2Fill"


class BsRecord2(rx.Component):
    library = "react-icons/bs"
    tag = "BsRecord2"


class BsRecycle(rx.Component):
    library = "react-icons/bs"
    tag = "BsRecycle"


class BsReddit(rx.Component):
    library = "react-icons/bs"
    tag = "BsReddit"


class BsRegex(rx.Component):
    library = "react-icons/bs"
    tag = "BsRegex"


class BsRepeat1(rx.Component):
    library = "react-icons/bs"
    tag = "BsRepeat1"


class BsRepeat(rx.Component):
    library = "react-icons/bs"
    tag = "BsRepeat"


class BsReplyAllFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsReplyAllFill"


class BsReplyAll(rx.Component):
    library = "react-icons/bs"
    tag = "BsReplyAll"


class BsReplyFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsReplyFill"


class BsReply(rx.Component):
    library = "react-icons/bs"
    tag = "BsReply"


class BsRewindBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsRewindBtnFill"


class BsRewindBtn(rx.Component):
    library = "react-icons/bs"
    tag = "BsRewindBtn"


class BsRewindCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsRewindCircleFill"


class BsRewindCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsRewindCircle"


class BsRewindFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsRewindFill"


class BsRewind(rx.Component):
    library = "react-icons/bs"
    tag = "BsRewind"


class BsRobot(rx.Component):
    library = "react-icons/bs"
    tag = "BsRobot"


class BsRocketFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsRocketFill"


class BsRocketTakeoffFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsRocketTakeoffFill"


class BsRocketTakeoff(rx.Component):
    library = "react-icons/bs"
    tag = "BsRocketTakeoff"


class BsRocket(rx.Component):
    library = "react-icons/bs"
    tag = "BsRocket"


class BsRouterFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsRouterFill"


class BsRouter(rx.Component):
    library = "react-icons/bs"
    tag = "BsRouter"


class BsRssFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsRssFill"


class BsRss(rx.Component):
    library = "react-icons/bs"
    tag = "BsRss"


class BsRulers(rx.Component):
    library = "react-icons/bs"
    tag = "BsRulers"


class BsSafeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSafeFill"


class BsSafe(rx.Component):
    library = "react-icons/bs"
    tag = "BsSafe"


class BsSafe2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSafe2Fill"


class BsSafe2(rx.Component):
    library = "react-icons/bs"
    tag = "BsSafe2"


class BsSaveFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSaveFill"


class BsSave(rx.Component):
    library = "react-icons/bs"
    tag = "BsSave"


class BsSave2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSave2Fill"


class BsSave2(rx.Component):
    library = "react-icons/bs"
    tag = "BsSave2"


class BsScissors(rx.Component):
    library = "react-icons/bs"
    tag = "BsScissors"


class BsScooter(rx.Component):
    library = "react-icons/bs"
    tag = "BsScooter"


class BsScrewdriver(rx.Component):
    library = "react-icons/bs"
    tag = "BsScrewdriver"


class BsSdCardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSdCardFill"


class BsSdCard(rx.Component):
    library = "react-icons/bs"
    tag = "BsSdCard"


class BsSearchHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSearchHeartFill"


class BsSearchHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsSearchHeart"


class BsSearch(rx.Component):
    library = "react-icons/bs"
    tag = "BsSearch"


class BsSegmentedNav(rx.Component):
    library = "react-icons/bs"
    tag = "BsSegmentedNav"


class BsSendCheckFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSendCheckFill"


class BsSendCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsSendCheck"


class BsSendDashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSendDashFill"


class BsSendDash(rx.Component):
    library = "react-icons/bs"
    tag = "BsSendDash"


class BsSendExclamationFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSendExclamationFill"


class BsSendExclamation(rx.Component):
    library = "react-icons/bs"
    tag = "BsSendExclamation"


class BsSendFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSendFill"


class BsSendPlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSendPlusFill"


class BsSendPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsSendPlus"


class BsSendSlashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSendSlashFill"


class BsSendSlash(rx.Component):
    library = "react-icons/bs"
    tag = "BsSendSlash"


class BsSendXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSendXFill"


class BsSendX(rx.Component):
    library = "react-icons/bs"
    tag = "BsSendX"


class BsSend(rx.Component):
    library = "react-icons/bs"
    tag = "BsSend"


class BsServer(rx.Component):
    library = "react-icons/bs"
    tag = "BsServer"


class BsShareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsShareFill"


class BsShare(rx.Component):
    library = "react-icons/bs"
    tag = "BsShare"


class BsShieldCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldCheck"


class BsShieldExclamation(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldExclamation"


class BsShieldFillCheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldFillCheck"


class BsShieldFillExclamation(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldFillExclamation"


class BsShieldFillMinus(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldFillMinus"


class BsShieldFillPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldFillPlus"


class BsShieldFillX(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldFillX"


class BsShieldFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldFill"


class BsShieldLockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldLockFill"


class BsShieldLock(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldLock"


class BsShieldMinus(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldMinus"


class BsShieldPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldPlus"


class BsShieldShaded(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldShaded"


class BsShieldSlashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldSlashFill"


class BsShieldSlash(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldSlash"


class BsShieldX(rx.Component):
    library = "react-icons/bs"
    tag = "BsShieldX"


class BsShield(rx.Component):
    library = "react-icons/bs"
    tag = "BsShield"


class BsShiftFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsShiftFill"


class BsShift(rx.Component):
    library = "react-icons/bs"
    tag = "BsShift"


class BsShopWindow(rx.Component):
    library = "react-icons/bs"
    tag = "BsShopWindow"


class BsShop(rx.Component):
    library = "react-icons/bs"
    tag = "BsShop"


class BsShuffle(rx.Component):
    library = "react-icons/bs"
    tag = "BsShuffle"


class BsSignDeadEndFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignDeadEndFill"


class BsSignDeadEnd(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignDeadEnd"


class BsSignDoNotEnterFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignDoNotEnterFill"


class BsSignDoNotEnter(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignDoNotEnter"


class BsSignIntersectionFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignIntersectionFill"


class BsSignIntersectionSideFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignIntersectionSideFill"


class BsSignIntersectionSide(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignIntersectionSide"


class BsSignIntersectionTFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignIntersectionTFill"


class BsSignIntersectionT(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignIntersectionT"


class BsSignIntersectionYFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignIntersectionYFill"


class BsSignIntersectionY(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignIntersectionY"


class BsSignIntersection(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignIntersection"


class BsSignMergeLeftFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignMergeLeftFill"


class BsSignMergeLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignMergeLeft"


class BsSignMergeRightFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignMergeRightFill"


class BsSignMergeRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignMergeRight"


class BsSignNoLeftTurnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignNoLeftTurnFill"


class BsSignNoLeftTurn(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignNoLeftTurn"


class BsSignNoParkingFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignNoParkingFill"


class BsSignNoParking(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignNoParking"


class BsSignNoRightTurnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignNoRightTurnFill"


class BsSignNoRightTurn(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignNoRightTurn"


class BsSignRailroadFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignRailroadFill"


class BsSignRailroad(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignRailroad"


class BsSignStopFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignStopFill"


class BsSignStopLightsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignStopLightsFill"


class BsSignStopLights(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignStopLights"


class BsSignStop(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignStop"


class BsSignTurnLeftFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignTurnLeftFill"


class BsSignTurnLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignTurnLeft"


class BsSignTurnRightFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignTurnRightFill"


class BsSignTurnRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignTurnRight"


class BsSignTurnSlightLeftFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignTurnSlightLeftFill"


class BsSignTurnSlightLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignTurnSlightLeft"


class BsSignTurnSlightRightFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignTurnSlightRightFill"


class BsSignTurnSlightRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignTurnSlightRight"


class BsSignYieldFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignYieldFill"


class BsSignYield(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignYield"


class BsSignal(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignal"


class BsSignpost2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignpost2Fill"


class BsSignpost2(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignpost2"


class BsSignpostFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignpostFill"


class BsSignpostSplitFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignpostSplitFill"


class BsSignpostSplit(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignpostSplit"


class BsSignpost(rx.Component):
    library = "react-icons/bs"
    tag = "BsSignpost"


class BsSimFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSimFill"


class BsSim(rx.Component):
    library = "react-icons/bs"
    tag = "BsSim"


class BsSinaWeibo(rx.Component):
    library = "react-icons/bs"
    tag = "BsSinaWeibo"


class BsSkipBackwardBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipBackwardBtnFill"


class BsSkipBackwardBtn(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipBackwardBtn"


class BsSkipBackwardCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipBackwardCircleFill"


class BsSkipBackwardCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipBackwardCircle"


class BsSkipBackwardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipBackwardFill"


class BsSkipBackward(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipBackward"


class BsSkipEndBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipEndBtnFill"


class BsSkipEndBtn(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipEndBtn"


class BsSkipEndCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipEndCircleFill"


class BsSkipEndCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipEndCircle"


class BsSkipEndFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipEndFill"


class BsSkipEnd(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipEnd"


class BsSkipForwardBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipForwardBtnFill"


class BsSkipForwardBtn(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipForwardBtn"


class BsSkipForwardCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipForwardCircleFill"


class BsSkipForwardCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipForwardCircle"


class BsSkipForwardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipForwardFill"


class BsSkipForward(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipForward"


class BsSkipStartBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipStartBtnFill"


class BsSkipStartBtn(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipStartBtn"


class BsSkipStartCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipStartCircleFill"


class BsSkipStartCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipStartCircle"


class BsSkipStartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipStartFill"


class BsSkipStart(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkipStart"


class BsSkype(rx.Component):
    library = "react-icons/bs"
    tag = "BsSkype"


class BsSlack(rx.Component):
    library = "react-icons/bs"
    tag = "BsSlack"


class BsSlashCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSlashCircleFill"


class BsSlashCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsSlashCircle"


class BsSlashLg(rx.Component):
    library = "react-icons/bs"
    tag = "BsSlashLg"


class BsSlashSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSlashSquareFill"


class BsSlashSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsSlashSquare"


class BsSlash(rx.Component):
    library = "react-icons/bs"
    tag = "BsSlash"


class BsSliders(rx.Component):
    library = "react-icons/bs"
    tag = "BsSliders"


class BsSliders2Vertical(rx.Component):
    library = "react-icons/bs"
    tag = "BsSliders2Vertical"


class BsSliders2(rx.Component):
    library = "react-icons/bs"
    tag = "BsSliders2"


class BsSmartwatch(rx.Component):
    library = "react-icons/bs"
    tag = "BsSmartwatch"


class BsSnapchat(rx.Component):
    library = "react-icons/bs"
    tag = "BsSnapchat"


class BsSnow(rx.Component):
    library = "react-icons/bs"
    tag = "BsSnow"


class BsSnow2(rx.Component):
    library = "react-icons/bs"
    tag = "BsSnow2"


class BsSnow3(rx.Component):
    library = "react-icons/bs"
    tag = "BsSnow3"


class BsSortAlphaDownAlt(rx.Component):
    library = "react-icons/bs"
    tag = "BsSortAlphaDownAlt"


class BsSortAlphaDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsSortAlphaDown"


class BsSortAlphaUpAlt(rx.Component):
    library = "react-icons/bs"
    tag = "BsSortAlphaUpAlt"


class BsSortAlphaUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsSortAlphaUp"


class BsSortDownAlt(rx.Component):
    library = "react-icons/bs"
    tag = "BsSortDownAlt"


class BsSortDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsSortDown"


class BsSortNumericDownAlt(rx.Component):
    library = "react-icons/bs"
    tag = "BsSortNumericDownAlt"


class BsSortNumericDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsSortNumericDown"


class BsSortNumericUpAlt(rx.Component):
    library = "react-icons/bs"
    tag = "BsSortNumericUpAlt"


class BsSortNumericUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsSortNumericUp"


class BsSortUpAlt(rx.Component):
    library = "react-icons/bs"
    tag = "BsSortUpAlt"


class BsSortUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsSortUp"


class BsSoundwave(rx.Component):
    library = "react-icons/bs"
    tag = "BsSoundwave"


class BsSpeakerFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSpeakerFill"


class BsSpeaker(rx.Component):
    library = "react-icons/bs"
    tag = "BsSpeaker"


class BsSpeedometer(rx.Component):
    library = "react-icons/bs"
    tag = "BsSpeedometer"


class BsSpeedometer2(rx.Component):
    library = "react-icons/bs"
    tag = "BsSpeedometer2"


class BsSpellcheck(rx.Component):
    library = "react-icons/bs"
    tag = "BsSpellcheck"


class BsSpotify(rx.Component):
    library = "react-icons/bs"
    tag = "BsSpotify"


class BsSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSquareFill"


class BsSquareHalf(rx.Component):
    library = "react-icons/bs"
    tag = "BsSquareHalf"


class BsSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsSquare"


class BsStackOverflow(rx.Component):
    library = "react-icons/bs"
    tag = "BsStackOverflow"


class BsStack(rx.Component):
    library = "react-icons/bs"
    tag = "BsStack"


class BsStarFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsStarFill"


class BsStarHalf(rx.Component):
    library = "react-icons/bs"
    tag = "BsStarHalf"


class BsStar(rx.Component):
    library = "react-icons/bs"
    tag = "BsStar"


class BsStars(rx.Component):
    library = "react-icons/bs"
    tag = "BsStars"


class BsSteam(rx.Component):
    library = "react-icons/bs"
    tag = "BsSteam"


class BsStickiesFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsStickiesFill"


class BsStickies(rx.Component):
    library = "react-icons/bs"
    tag = "BsStickies"


class BsStickyFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsStickyFill"


class BsSticky(rx.Component):
    library = "react-icons/bs"
    tag = "BsSticky"


class BsStopBtnFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsStopBtnFill"


class BsStopBtn(rx.Component):
    library = "react-icons/bs"
    tag = "BsStopBtn"


class BsStopCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsStopCircleFill"


class BsStopCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsStopCircle"


class BsStopFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsStopFill"


class BsStop(rx.Component):
    library = "react-icons/bs"
    tag = "BsStop"


class BsStoplightsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsStoplightsFill"


class BsStoplights(rx.Component):
    library = "react-icons/bs"
    tag = "BsStoplights"


class BsStopwatchFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsStopwatchFill"


class BsStopwatch(rx.Component):
    library = "react-icons/bs"
    tag = "BsStopwatch"


class BsStrava(rx.Component):
    library = "react-icons/bs"
    tag = "BsStrava"


class BsStripe(rx.Component):
    library = "react-icons/bs"
    tag = "BsStripe"


class BsSubscript(rx.Component):
    library = "react-icons/bs"
    tag = "BsSubscript"


class BsSubtract(rx.Component):
    library = "react-icons/bs"
    tag = "BsSubtract"


class BsSuitClubFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSuitClubFill"


class BsSuitClub(rx.Component):
    library = "react-icons/bs"
    tag = "BsSuitClub"


class BsSuitDiamondFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSuitDiamondFill"


class BsSuitDiamond(rx.Component):
    library = "react-icons/bs"
    tag = "BsSuitDiamond"


class BsSuitHeartFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSuitHeartFill"


class BsSuitHeart(rx.Component):
    library = "react-icons/bs"
    tag = "BsSuitHeart"


class BsSuitSpadeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSuitSpadeFill"


class BsSuitSpade(rx.Component):
    library = "react-icons/bs"
    tag = "BsSuitSpade"


class BsSunFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSunFill"


class BsSun(rx.Component):
    library = "react-icons/bs"
    tag = "BsSun"


class BsSunglasses(rx.Component):
    library = "react-icons/bs"
    tag = "BsSunglasses"


class BsSunriseFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSunriseFill"


class BsSunrise(rx.Component):
    library = "react-icons/bs"
    tag = "BsSunrise"


class BsSunsetFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsSunsetFill"


class BsSunset(rx.Component):
    library = "react-icons/bs"
    tag = "BsSunset"


class BsSuperscript(rx.Component):
    library = "react-icons/bs"
    tag = "BsSuperscript"


class BsSymmetryHorizontal(rx.Component):
    library = "react-icons/bs"
    tag = "BsSymmetryHorizontal"


class BsSymmetryVertical(rx.Component):
    library = "react-icons/bs"
    tag = "BsSymmetryVertical"


class BsTable(rx.Component):
    library = "react-icons/bs"
    tag = "BsTable"


class BsTabletFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTabletFill"


class BsTabletLandscapeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTabletLandscapeFill"


class BsTabletLandscape(rx.Component):
    library = "react-icons/bs"
    tag = "BsTabletLandscape"


class BsTablet(rx.Component):
    library = "react-icons/bs"
    tag = "BsTablet"


class BsTagFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTagFill"


class BsTag(rx.Component):
    library = "react-icons/bs"
    tag = "BsTag"


class BsTagsFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTagsFill"


class BsTags(rx.Component):
    library = "react-icons/bs"
    tag = "BsTags"


class BsTaxiFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTaxiFrontFill"


class BsTaxiFront(rx.Component):
    library = "react-icons/bs"
    tag = "BsTaxiFront"


class BsTelegram(rx.Component):
    library = "react-icons/bs"
    tag = "BsTelegram"


class BsTelephoneFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTelephoneFill"


class BsTelephoneForwardFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTelephoneForwardFill"


class BsTelephoneForward(rx.Component):
    library = "react-icons/bs"
    tag = "BsTelephoneForward"


class BsTelephoneInboundFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTelephoneInboundFill"


class BsTelephoneInbound(rx.Component):
    library = "react-icons/bs"
    tag = "BsTelephoneInbound"


class BsTelephoneMinusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTelephoneMinusFill"


class BsTelephoneMinus(rx.Component):
    library = "react-icons/bs"
    tag = "BsTelephoneMinus"


class BsTelephoneOutboundFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTelephoneOutboundFill"


class BsTelephoneOutbound(rx.Component):
    library = "react-icons/bs"
    tag = "BsTelephoneOutbound"


class BsTelephonePlusFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTelephonePlusFill"


class BsTelephonePlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsTelephonePlus"


class BsTelephoneXFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTelephoneXFill"


class BsTelephoneX(rx.Component):
    library = "react-icons/bs"
    tag = "BsTelephoneX"


class BsTelephone(rx.Component):
    library = "react-icons/bs"
    tag = "BsTelephone"


class BsTencentQq(rx.Component):
    library = "react-icons/bs"
    tag = "BsTencentQq"


class BsTerminalDash(rx.Component):
    library = "react-icons/bs"
    tag = "BsTerminalDash"


class BsTerminalFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTerminalFill"


class BsTerminalPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsTerminalPlus"


class BsTerminalSplit(rx.Component):
    library = "react-icons/bs"
    tag = "BsTerminalSplit"


class BsTerminalX(rx.Component):
    library = "react-icons/bs"
    tag = "BsTerminalX"


class BsTerminal(rx.Component):
    library = "react-icons/bs"
    tag = "BsTerminal"


class BsTextCenter(rx.Component):
    library = "react-icons/bs"
    tag = "BsTextCenter"


class BsTextIndentLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsTextIndentLeft"


class BsTextIndentRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsTextIndentRight"


class BsTextLeft(rx.Component):
    library = "react-icons/bs"
    tag = "BsTextLeft"


class BsTextParagraph(rx.Component):
    library = "react-icons/bs"
    tag = "BsTextParagraph"


class BsTextRight(rx.Component):
    library = "react-icons/bs"
    tag = "BsTextRight"


class BsTextWrap(rx.Component):
    library = "react-icons/bs"
    tag = "BsTextWrap"


class BsTextareaResize(rx.Component):
    library = "react-icons/bs"
    tag = "BsTextareaResize"


class BsTextareaT(rx.Component):
    library = "react-icons/bs"
    tag = "BsTextareaT"


class BsTextarea(rx.Component):
    library = "react-icons/bs"
    tag = "BsTextarea"


class BsThermometerHalf(rx.Component):
    library = "react-icons/bs"
    tag = "BsThermometerHalf"


class BsThermometerHigh(rx.Component):
    library = "react-icons/bs"
    tag = "BsThermometerHigh"


class BsThermometerLow(rx.Component):
    library = "react-icons/bs"
    tag = "BsThermometerLow"


class BsThermometerSnow(rx.Component):
    library = "react-icons/bs"
    tag = "BsThermometerSnow"


class BsThermometerSun(rx.Component):
    library = "react-icons/bs"
    tag = "BsThermometerSun"


class BsThermometer(rx.Component):
    library = "react-icons/bs"
    tag = "BsThermometer"


class BsThreeDotsVertical(rx.Component):
    library = "react-icons/bs"
    tag = "BsThreeDotsVertical"


class BsThreeDots(rx.Component):
    library = "react-icons/bs"
    tag = "BsThreeDots"


class BsThunderboltFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsThunderboltFill"


class BsThunderbolt(rx.Component):
    library = "react-icons/bs"
    tag = "BsThunderbolt"


class BsTicketDetailedFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTicketDetailedFill"


class BsTicketDetailed(rx.Component):
    library = "react-icons/bs"
    tag = "BsTicketDetailed"


class BsTicketFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTicketFill"


class BsTicketPerforatedFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTicketPerforatedFill"


class BsTicketPerforated(rx.Component):
    library = "react-icons/bs"
    tag = "BsTicketPerforated"


class BsTicket(rx.Component):
    library = "react-icons/bs"
    tag = "BsTicket"


class BsTiktok(rx.Component):
    library = "react-icons/bs"
    tag = "BsTiktok"


class BsToggleOff(rx.Component):
    library = "react-icons/bs"
    tag = "BsToggleOff"


class BsToggleOn(rx.Component):
    library = "react-icons/bs"
    tag = "BsToggleOn"


class BsToggle2Off(rx.Component):
    library = "react-icons/bs"
    tag = "BsToggle2Off"


class BsToggle2On(rx.Component):
    library = "react-icons/bs"
    tag = "BsToggle2On"


class BsToggles(rx.Component):
    library = "react-icons/bs"
    tag = "BsToggles"


class BsToggles2(rx.Component):
    library = "react-icons/bs"
    tag = "BsToggles2"


class BsTools(rx.Component):
    library = "react-icons/bs"
    tag = "BsTools"


class BsTornado(rx.Component):
    library = "react-icons/bs"
    tag = "BsTornado"


class BsTrainFreightFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTrainFreightFrontFill"


class BsTrainFreightFront(rx.Component):
    library = "react-icons/bs"
    tag = "BsTrainFreightFront"


class BsTrainFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTrainFrontFill"


class BsTrainFront(rx.Component):
    library = "react-icons/bs"
    tag = "BsTrainFront"


class BsTrainLightrailFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTrainLightrailFrontFill"


class BsTrainLightrailFront(rx.Component):
    library = "react-icons/bs"
    tag = "BsTrainLightrailFront"


class BsTranslate(rx.Component):
    library = "react-icons/bs"
    tag = "BsTranslate"


class BsTrashFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTrashFill"


class BsTrash(rx.Component):
    library = "react-icons/bs"
    tag = "BsTrash"


class BsTrash2Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTrash2Fill"


class BsTrash2(rx.Component):
    library = "react-icons/bs"
    tag = "BsTrash2"


class BsTrash3Fill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTrash3Fill"


class BsTrash3(rx.Component):
    library = "react-icons/bs"
    tag = "BsTrash3"


class BsTreeFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTreeFill"


class BsTree(rx.Component):
    library = "react-icons/bs"
    tag = "BsTree"


class BsTrello(rx.Component):
    library = "react-icons/bs"
    tag = "BsTrello"


class BsTriangleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTriangleFill"


class BsTriangleHalf(rx.Component):
    library = "react-icons/bs"
    tag = "BsTriangleHalf"


class BsTriangle(rx.Component):
    library = "react-icons/bs"
    tag = "BsTriangle"


class BsTrophyFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTrophyFill"


class BsTrophy(rx.Component):
    library = "react-icons/bs"
    tag = "BsTrophy"


class BsTropicalStorm(rx.Component):
    library = "react-icons/bs"
    tag = "BsTropicalStorm"


class BsTruckFlatbed(rx.Component):
    library = "react-icons/bs"
    tag = "BsTruckFlatbed"


class BsTruckFrontFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTruckFrontFill"


class BsTruckFront(rx.Component):
    library = "react-icons/bs"
    tag = "BsTruckFront"


class BsTruck(rx.Component):
    library = "react-icons/bs"
    tag = "BsTruck"


class BsTsunami(rx.Component):
    library = "react-icons/bs"
    tag = "BsTsunami"


class BsTvFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsTvFill"


class BsTv(rx.Component):
    library = "react-icons/bs"
    tag = "BsTv"


class BsTwitch(rx.Component):
    library = "react-icons/bs"
    tag = "BsTwitch"


class BsTwitter(rx.Component):
    library = "react-icons/bs"
    tag = "BsTwitter"


class BsTypeBold(rx.Component):
    library = "react-icons/bs"
    tag = "BsTypeBold"


class BsTypeH1(rx.Component):
    library = "react-icons/bs"
    tag = "BsTypeH1"


class BsTypeH2(rx.Component):
    library = "react-icons/bs"
    tag = "BsTypeH2"


class BsTypeH3(rx.Component):
    library = "react-icons/bs"
    tag = "BsTypeH3"


class BsTypeItalic(rx.Component):
    library = "react-icons/bs"
    tag = "BsTypeItalic"


class BsTypeStrikethrough(rx.Component):
    library = "react-icons/bs"
    tag = "BsTypeStrikethrough"


class BsTypeUnderline(rx.Component):
    library = "react-icons/bs"
    tag = "BsTypeUnderline"


class BsType(rx.Component):
    library = "react-icons/bs"
    tag = "BsType"


class BsUbuntu(rx.Component):
    library = "react-icons/bs"
    tag = "BsUbuntu"


class BsUiChecksGrid(rx.Component):
    library = "react-icons/bs"
    tag = "BsUiChecksGrid"


class BsUiChecks(rx.Component):
    library = "react-icons/bs"
    tag = "BsUiChecks"


class BsUiRadiosGrid(rx.Component):
    library = "react-icons/bs"
    tag = "BsUiRadiosGrid"


class BsUiRadios(rx.Component):
    library = "react-icons/bs"
    tag = "BsUiRadios"


class BsUmbrellaFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsUmbrellaFill"


class BsUmbrella(rx.Component):
    library = "react-icons/bs"
    tag = "BsUmbrella"


class BsUnindent(rx.Component):
    library = "react-icons/bs"
    tag = "BsUnindent"


class BsUnion(rx.Component):
    library = "react-icons/bs"
    tag = "BsUnion"


class BsUnity(rx.Component):
    library = "react-icons/bs"
    tag = "BsUnity"


class BsUniversalAccessCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsUniversalAccessCircle"


class BsUniversalAccess(rx.Component):
    library = "react-icons/bs"
    tag = "BsUniversalAccess"


class BsUnlockFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsUnlockFill"


class BsUnlock(rx.Component):
    library = "react-icons/bs"
    tag = "BsUnlock"


class BsUpcScan(rx.Component):
    library = "react-icons/bs"
    tag = "BsUpcScan"


class BsUpc(rx.Component):
    library = "react-icons/bs"
    tag = "BsUpc"


class BsUpload(rx.Component):
    library = "react-icons/bs"
    tag = "BsUpload"


class BsUsbCFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsUsbCFill"


class BsUsbC(rx.Component):
    library = "react-icons/bs"
    tag = "BsUsbC"


class BsUsbDriveFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsUsbDriveFill"


class BsUsbDrive(rx.Component):
    library = "react-icons/bs"
    tag = "BsUsbDrive"


class BsUsbFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsUsbFill"


class BsUsbMicroFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsUsbMicroFill"


class BsUsbMicro(rx.Component):
    library = "react-icons/bs"
    tag = "BsUsbMicro"


class BsUsbMiniFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsUsbMiniFill"


class BsUsbMini(rx.Component):
    library = "react-icons/bs"
    tag = "BsUsbMini"


class BsUsbPlugFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsUsbPlugFill"


class BsUsbPlug(rx.Component):
    library = "react-icons/bs"
    tag = "BsUsbPlug"


class BsUsbSymbol(rx.Component):
    library = "react-icons/bs"
    tag = "BsUsbSymbol"


class BsUsb(rx.Component):
    library = "react-icons/bs"
    tag = "BsUsb"


class BsValentine(rx.Component):
    library = "react-icons/bs"
    tag = "BsValentine"


class BsValentine2(rx.Component):
    library = "react-icons/bs"
    tag = "BsValentine2"


class BsVectorPen(rx.Component):
    library = "react-icons/bs"
    tag = "BsVectorPen"


class BsViewList(rx.Component):
    library = "react-icons/bs"
    tag = "BsViewList"


class BsViewStacked(rx.Component):
    library = "react-icons/bs"
    tag = "BsViewStacked"


class BsVimeo(rx.Component):
    library = "react-icons/bs"
    tag = "BsVimeo"


class BsVinylFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsVinylFill"


class BsVinyl(rx.Component):
    library = "react-icons/bs"
    tag = "BsVinyl"


class BsVirus(rx.Component):
    library = "react-icons/bs"
    tag = "BsVirus"


class BsVirus2(rx.Component):
    library = "react-icons/bs"
    tag = "BsVirus2"


class BsVoicemail(rx.Component):
    library = "react-icons/bs"
    tag = "BsVoicemail"


class BsVolumeDownFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsVolumeDownFill"


class BsVolumeDown(rx.Component):
    library = "react-icons/bs"
    tag = "BsVolumeDown"


class BsVolumeMuteFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsVolumeMuteFill"


class BsVolumeMute(rx.Component):
    library = "react-icons/bs"
    tag = "BsVolumeMute"


class BsVolumeOffFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsVolumeOffFill"


class BsVolumeOff(rx.Component):
    library = "react-icons/bs"
    tag = "BsVolumeOff"


class BsVolumeUpFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsVolumeUpFill"


class BsVolumeUp(rx.Component):
    library = "react-icons/bs"
    tag = "BsVolumeUp"


class BsVr(rx.Component):
    library = "react-icons/bs"
    tag = "BsVr"


class BsWalletFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsWalletFill"


class BsWallet(rx.Component):
    library = "react-icons/bs"
    tag = "BsWallet"


class BsWallet2(rx.Component):
    library = "react-icons/bs"
    tag = "BsWallet2"


class BsWatch(rx.Component):
    library = "react-icons/bs"
    tag = "BsWatch"


class BsWater(rx.Component):
    library = "react-icons/bs"
    tag = "BsWater"


class BsWebcamFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsWebcamFill"


class BsWebcam(rx.Component):
    library = "react-icons/bs"
    tag = "BsWebcam"


class BsWechat(rx.Component):
    library = "react-icons/bs"
    tag = "BsWechat"


class BsWhatsapp(rx.Component):
    library = "react-icons/bs"
    tag = "BsWhatsapp"


class BsWifi1(rx.Component):
    library = "react-icons/bs"
    tag = "BsWifi1"


class BsWifi2(rx.Component):
    library = "react-icons/bs"
    tag = "BsWifi2"


class BsWifiOff(rx.Component):
    library = "react-icons/bs"
    tag = "BsWifiOff"


class BsWifi(rx.Component):
    library = "react-icons/bs"
    tag = "BsWifi"


class BsWikipedia(rx.Component):
    library = "react-icons/bs"
    tag = "BsWikipedia"


class BsWind(rx.Component):
    library = "react-icons/bs"
    tag = "BsWind"


class BsWindowDash(rx.Component):
    library = "react-icons/bs"
    tag = "BsWindowDash"


class BsWindowDesktop(rx.Component):
    library = "react-icons/bs"
    tag = "BsWindowDesktop"


class BsWindowDock(rx.Component):
    library = "react-icons/bs"
    tag = "BsWindowDock"


class BsWindowFullscreen(rx.Component):
    library = "react-icons/bs"
    tag = "BsWindowFullscreen"


class BsWindowPlus(rx.Component):
    library = "react-icons/bs"
    tag = "BsWindowPlus"


class BsWindowSidebar(rx.Component):
    library = "react-icons/bs"
    tag = "BsWindowSidebar"


class BsWindowSplit(rx.Component):
    library = "react-icons/bs"
    tag = "BsWindowSplit"


class BsWindowStack(rx.Component):
    library = "react-icons/bs"
    tag = "BsWindowStack"


class BsWindowX(rx.Component):
    library = "react-icons/bs"
    tag = "BsWindowX"


class BsWindow(rx.Component):
    library = "react-icons/bs"
    tag = "BsWindow"


class BsWindows(rx.Component):
    library = "react-icons/bs"
    tag = "BsWindows"


class BsWordpress(rx.Component):
    library = "react-icons/bs"
    tag = "BsWordpress"


class BsWrenchAdjustableCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsWrenchAdjustableCircleFill"


class BsWrenchAdjustableCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsWrenchAdjustableCircle"


class BsWrenchAdjustable(rx.Component):
    library = "react-icons/bs"
    tag = "BsWrenchAdjustable"


class BsWrench(rx.Component):
    library = "react-icons/bs"
    tag = "BsWrench"


class BsXCircleFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsXCircleFill"


class BsXCircle(rx.Component):
    library = "react-icons/bs"
    tag = "BsXCircle"


class BsXDiamondFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsXDiamondFill"


class BsXDiamond(rx.Component):
    library = "react-icons/bs"
    tag = "BsXDiamond"


class BsXLg(rx.Component):
    library = "react-icons/bs"
    tag = "BsXLg"


class BsXOctagonFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsXOctagonFill"


class BsXOctagon(rx.Component):
    library = "react-icons/bs"
    tag = "BsXOctagon"


class BsXSquareFill(rx.Component):
    library = "react-icons/bs"
    tag = "BsXSquareFill"


class BsXSquare(rx.Component):
    library = "react-icons/bs"
    tag = "BsXSquare"


class BsX(rx.Component):
    library = "react-icons/bs"
    tag = "BsX"


class BsXbox(rx.Component):
    library = "react-icons/bs"
    tag = "BsXbox"


class BsYelp(rx.Component):
    library = "react-icons/bs"
    tag = "BsYelp"


class BsYinYang(rx.Component):
    library = "react-icons/bs"
    tag = "BsYinYang"


class BsYoutube(rx.Component):
    library = "react-icons/bs"
    tag = "BsYoutube"


class BsZoomIn(rx.Component):
    library = "react-icons/bs"
    tag = "BsZoomIn"


class BsZoomOut(rx.Component):
    library = "react-icons/bs"
    tag = "BsZoomOut"


